@@ -39,11 +39,11 @@
 #include <QSplitter>
 #include <QDesktopServices>
 #include <QBuffer>
-#include <QLocale>
 
 #include "Table.h"
 #include "ScriptingEnv.h"
 #include "Script.h"
+#include "plot2D/TranslateCurveTool.h"
 
 class QPixmap;
 class QCloseEvent;
@@ -83,7 +83,6 @@ class TableStatistics;
 class CurveRangeDialog;
 class LegendWidget;
 class ArrowMarker;
-class ImageMarker;
 class TextEditor;
 class AssociationsDialog;
 
@@ -164,6 +163,9 @@ public:
 	QCompleter* completer(){return d_completer;};
 	void enableCompletion(bool on = true);
 
+	QLocale clipboardLocale(){return d_clipboard_locale;};
+	void setClipboardLocale(const QLocale& locale){d_clipboard_locale = locale;};
+
 public slots:
 	//! \name Projects and Project Files
 	//@{
@@ -217,9 +219,6 @@ public slots:
 	void updateAppFonts();
 	void setAppColors(const QColor& wc,const QColor& pc,const QColor& tpc, bool force = false);
 
-	QLocale locale(){return d_locale;};
-	void setLocale(const QLocale& l){d_locale = l;};
-
 	void initWindow();
 	//@}
 
@@ -235,7 +234,11 @@ public slots:
 	MultiLayer* multilayerPlot(const QStringList& colList);
 	void connectMultilayerPlot(MultiLayer *g);
 	void addLayer();
+	void addInsetLayer(bool curves = false);
+	void addInsetCurveLayer();
 	void deleteLayer();
+	void extractGraphs();
+    void extractLayers();
 
 	//! Creates a new spectrogram graph
   	MultiLayer* plotSpectrogram(Matrix *m, Graph::CurveType type);
@@ -341,7 +344,7 @@ public slots:
 	void rotateMatrixMinus90();
 	void viewMatrixImage();
 	void viewMatrixTable();
-	void exportMatrix();
+	void exportMatrix(const QString& exportFilter = QString::null);
 	void setMatrixGrayScale();
 	void setMatrixRainbowScale();
 	void viewMatrixColumnRow();
@@ -408,8 +411,6 @@ public slots:
 	//@{
 	void setPreferences(Graph* g);
 	void setGraphDefaultSettings(bool autoscale,bool scaleFonts,bool resizeLayers,bool antialiasing);
-	void setLegendDefaultSettings(int frame, const QFont& font,
-							 const QColor& textCol, const QColor& backgroundCol);
 	void setArrowDefaultSettings(double lineWidth,  const QColor& c, Qt::PenStyle style,
 								int headLength, int headAngle, bool fillHead);
 
@@ -429,6 +430,8 @@ public slots:
 	void plotVectXYXY();
 	void plotVectXYAM();
 	void plotBoxDiagram();
+	void plotDoubleYAxis();
+	void zoomRectanglePlot();
 
     //! Check whether a table is valid for a 3D plot and display an appropriate error if not
     bool validFor3DPlot(Table *table);
@@ -444,13 +447,13 @@ public slots:
 	void pixelLineProfile();
 	void loadImage();
 	void loadImage(const QString& fn);
-  	Matrix* importImage(const QString& = QString());
+  	Matrix* importImage(const QString& = QString(), bool newWindow = false);
 	//@}
 
 	//! \name Export and Print
 	//@{
 	void exportLayer();
-	void exportGraph();
+	void exportGraph(const QString& exportFilter = QString::null);
 	void exportAllGraphs();
 	void exportPDF();
 	void print();
@@ -477,8 +480,6 @@ public slots:
 	void maximizeWindow(Q3ListViewItem * lbi = 0);
 	void maximizeWindow(MdiSubWindow *w);
 	void minimizeWindow(MdiSubWindow *w = 0);
-    //! Changes the geometry of the active MDI window
-    void setWindowGeometry(int x, int y, int w, int h);
 
 	void updateWindowStatus(MdiSubWindow* );
 
@@ -577,7 +578,8 @@ public slots:
 	void drawArrow();
 	void drawPoints();
 	void addText();
-	void disableAddText();
+	void addTexFormula();
+	void addRectangle();
 	void addImage();
 	void zoomIn();
 	void zoomOut();
@@ -642,7 +644,7 @@ public slots:
 	void showGeneralPlotDialog();
 	void showResults(bool ok);
 	void showResults(const QString& s, bool ok=true);
-	void showTextDialog();
+	void showEnrichementDialog();
 	void showLineDialog();
 	void showTitleDialog();
 	void showExportASCIIDialog();
@@ -683,6 +685,7 @@ public slots:
 	void chooseHelpFolder();
 	void showPlotWizard();
 	void showFitPolynomDialog();
+    void showFrequencyCountDialog();
 	void showIntegrationDialog();
 	void showInterpolationDialog();
 	void showExpGrowthDialog();
@@ -693,7 +696,6 @@ public slots:
 	void showRowStatistics();
 	void showColStatistics();
 	void showFitDialog();
-	void showImageDialog();
 	void showLayerDialog();
 	void showPreferencesDialog();
 	void showMatrixDialog();
@@ -713,7 +715,7 @@ public slots:
 	//@}
 
 	void translateCurveHor();
-	void translateCurveVert();
+	void translateCurve(TranslateCurveTool::Direction direction = TranslateCurveTool::Vertical);
 
 	//! Removes the curve identified by a key stored in the data() of actionRemoveCurve.
 	void removeCurve();
@@ -1021,6 +1023,7 @@ private slots:
 
 	void hideSelectedColumns();
 	void showAllColumns();
+	void closedLastCopiedLayer(){lastCopiedLayer = NULL;};
 
 // TODO: a lot of this stuff should be private
 public:
@@ -1046,16 +1049,14 @@ public:
 	bool d_inform_rename_table;
 	QString d_export_col_separator;
 	bool d_export_col_names, d_export_table_selection, d_export_col_comment;
-
-    bool d_thousands_sep;
     //! Last selected filter in export image dialog
     QString d_image_export_filter;
-    bool d_keep_plot_aspect;
-    int d_export_vector_size;
     bool d_export_transparency;
     int d_export_quality;
     int d_export_resolution;
     bool d_export_color;
+	//! Locale used to specify the decimal separators in imported ASCII files
+	QLocale d_clipboard_locale;
 	//! Locale used to specify the decimal separators in imported ASCII files
 	QLocale d_ASCII_import_locale;
 	//! End of line convention used to import ASCII files.
@@ -1106,8 +1107,10 @@ public:
 	//! File version code used when opening project files (= maj * 100 + min * 10 + patch)
 	int d_file_version;
 
+	QColor d_rect_default_background;
+	QBrush d_rect_default_brush;
 	QColor workspaceColor, panelsColor, panelsTextColor;
-	QColor d_graph_background_color, d_graph_canvas_color, d_graph_border_color;
+	QColor d_graph_background_color, d_graph_canvas_color, d_graph_border_color, d_canvas_frame_color;
 	int d_graph_background_opacity, d_graph_canvas_opacity, d_graph_border_width;
 	QString appStyle, workingDir;
 
@@ -1119,10 +1122,11 @@ public:
 	bool titleOn, autoSave, drawBackbones, allAxesOn, autoscale2DPlots, antialiasing2DPlots;
 	int majTicksStyle, minTicksStyle, legendFrameStyle, autoSaveTime, axesLineWidth, canvasFrameWidth;
 	QColor legendBackground, legendTextColor, defaultArrowColor;
-	int defaultArrowHeadLength, defaultArrowHeadAngle;
+	int defaultArrowHeadLength, defaultArrowHeadAngle, d_legend_default_angle;
 	double defaultArrowLineWidth, defaultCurveLineWidth;
 	bool defaultArrowHeadFill;
 	Qt::PenStyle defaultArrowLineStyle;
+	QPen d_frame_widget_pen;
 	int majTicksLength, minTicksLength, defaultPlotMargin;
 	int defaultCurveStyle, defaultSymbolSize;
 	QFont appFont, plot3DTitleFont, plot3DNumbersFont, plot3DAxesFont;
@@ -1144,9 +1148,8 @@ public:
 
 	//! \name variables used when user copy/paste markers
 	//@{
-	LegendWidget *d_text_copy;
+	FrameWidget *d_enrichement_copy;
 	ArrowMarker *d_arrow_copy;
-	ImageMarker *d_image_copy;
 	//@}
 
 	//! Equals true if an automatical search for updates was performed on start-up otherwise is set to false;
@@ -1158,7 +1161,6 @@ public:
 private:
 	MdiSubWindow *d_active_window;
     TextEditor *d_text_editor;
-    QLocale d_locale;
 	// Flag telling if table values should be automatically recalculated when values in a column are modified.
 	bool d_auto_update_table_values;
     int d_matrix_undo_stack_size;
@@ -1223,19 +1225,20 @@ private:
 	QAction *actionPlotHorizontalBars, *actionPlotArea, *actionPlotPie, *actionPlotVectXYAM, *actionPlotVectXYXY;
     QAction *actionPlotHistogram, *actionPlotStackedHistograms, *actionPlot2VerticalLayers, *actionPlot2HorizontalLayers, *actionPlot4Layers, *actionPlotStackedLayers;
     QAction *actionPlot3DRibbon, *actionPlot3DBars, *actionPlot3DScatter, *actionPlot3DTrajectory;
+    QAction *actionPlotDoubleYAxis, *actionAddInsetLayer, *actionAddInsetCurveLayer;
     QAction *actionShowColStatistics, *actionShowRowStatistics, *actionShowIntDialog, *actionIntegrate;
     QAction *actionDifferentiate, *actionFitLinear, *actionShowFitPolynomDialog;
     QAction *actionShowExpDecayDialog, *actionShowTwoExpDecayDialog, *actionShowExpDecay3Dialog;
     QAction *actionFitExpGrowth, *actionFitSigmoidal, *actionFitGauss, *actionFitLorentz, *actionShowFitDialog;
     QAction *actionShowAxisDialog, *actionShowTitleDialog;
     QAction *actionShowColumnOptionsDialog, *actionShowColumnValuesDialog, *actionShowColsDialog, *actionShowRowsDialog;
-    QAction *actionTableRecalculate;
+    QAction *actionTableRecalculate, *actionExtractGraphs, *actionExtractLayers;
     QAction *actionAbout, *actionShowHelp, *actionChooseHelpFolder;
     QAction *actionRename, *actionCloseWindow, *actionConvertTable;
     QAction *actionAddColToTable, *actionDeleteLayer, *actionInterpolate;
     QAction *actionResizeActiveWindow, *actionHideActiveWindow;
     QAction *actionShowMoreWindows, *actionPixelLineProfile, *actionIntensityTable;
-    QAction *actionShowLineDialog, *actionShowImageDialog, *actionShowTextDialog;
+    QAction *actionShowLineDialog, *actionShowTextDialog;
     QAction *actionActivateWindow, *actionMinimizeWindow, *actionMaximizeWindow, *actionHideWindow, *actionResizeWindow;
     QAction *actionEditSurfacePlot, *actionAdd3DData;
 	QAction *actionMatrixDeterminant, *actionSetMatrixProperties, *actionConvertMatrixXYZ, *actionConvertMatrixYXZ;
@@ -1256,9 +1259,9 @@ private:
 	QAction *actionNextWindow, *actionPrevWindow;
 	QAction *actionScriptingLang, *actionRestartScripting, *actionClearTable, *actionGoToRow, *actionGoToColumn;
 	QAction *actionNoteExecute, *actionNoteExecuteAll, *actionNoteEvaluate, *actionSaveNote;
-	QAction *actionShowScriptWindow;
+	QAction *actionShowScriptWindow, *actionFrequencyCount;
 	QAction *actionAnimate, *actionPerspective, *actionFitFrame, *actionResetRotation;
-    QAction *actionDeleteRows, *actionDrawPoints;
+    QAction *actionDeleteRows, *actionDrawPoints, *actionAddZoomPlot;
 	QAction *btnCursor, *btnSelect, *btnPicker, *btnRemovePoints, *btnMovePoints;
 	QAction *btnZoomIn, *btnZoomOut, *btnPointer, *btnLine, *btnArrow;
 	QAction *actionFlipMatrixVertically, *actionFlipMatrixHorizontally, *actionRotateMatrix;
@@ -1272,7 +1275,7 @@ private:
 	QAction *Box, *Frame, *None;
     QAction *front, *back, *right, *left, *ceil, *floor, *floordata, *flooriso, *floornone;
     QAction *wireframe, *hiddenline, *polygon, *filledmesh, *pointstyle, *barstyle, *conestyle, *crossHairStyle;
-    QAction *actionShowUndoStack, *actionShowNoteLineNumbers;
+    QAction *actionShowUndoStack, *actionShowNoteLineNumbers, *actionAddFormula, *actionAddRectangle;
     QActionGroup *coord, *floorstyle, *grids, *plotstyle, *dataTools;
     QList<QAction *> d_user_actions;
     QUndoView *d_undo_view;
