@@ -640,9 +640,11 @@ void ConfigDialog::initAppPage()
 	boxSearchUpdates->setChecked(app->autoSearchUpdates);
 	topBoxLayout->addWidget( boxSearchUpdates, 9, 0, 1, 2 );
 
+#ifdef SCRIPTING_PYTHON
     completionBox = new QCheckBox();
 	completionBox->setChecked(app->d_completion);
 	topBoxLayout->addWidget(completionBox, 10, 0);
+#endif
 
 	lineNumbersBox = new QCheckBox();
 	lineNumbersBox->setChecked(app->d_note_line_numbers);
@@ -709,8 +711,17 @@ void ConfigDialog::initAppPage()
 
     boxThousandsSeparator = new QCheckBox();
     boxThousandsSeparator->setChecked(app->locale().numberOptions() & QLocale::OmitGroupSeparator);
-    numericFormatLayout->addWidget(boxThousandsSeparator, 2, 0);
+    numericFormatLayout->addWidget(boxThousandsSeparator, 1, 2);
 
+	lblClipboardSeparator = new QLabel();
+    numericFormatLayout->addWidget(lblClipboardSeparator, 2, 0 );
+	boxClipboardLocale = new QComboBox();
+	boxClipboardLocale->addItem(tr("System Locale Setting"));
+	boxClipboardLocale->addItem("1,000.0");
+	boxClipboardLocale->addItem("1.000,0");
+	boxClipboardLocale->addItem("1 000,0");
+	numericFormatLayout->addWidget(boxClipboardLocale, 2, 1);
+	
 	numericFormatLayout->setRowStretch(3, 1);
 	appTabWidget->addTab( numericFormatPage, QString() );
 
@@ -1061,7 +1072,9 @@ void ConfigDialog::languageChange()
 	boxInitWindow->addItem(tr("Empty Graph"));
 	boxInitWindow->addItem(tr("Note"));
 	boxInitWindow->setCurrentIndex((int)app->d_init_window_type);
+#ifdef SCRIPTING_PYTHON
     completionBox->setText(tr("&Enable autocompletion (Ctrl+U)"));
+#endif
     lineNumbersBox->setText(tr("&Display line numbers in Notes"));
 
 	lblAppPrecision->setText(tr("Number of Decimal Digits"));
@@ -1081,6 +1094,20 @@ void ConfigDialog::languageChange()
     else if (locale.name() == QLocale(QLocale::French).name())
         boxDecimalSeparator->setCurrentIndex(3);
 
+	lblClipboardSeparator->setText(tr("Clipboard Decimal Separators"));
+	boxClipboardLocale->clear();
+	boxClipboardLocale->addItem(tr("System Locale Setting"));
+	boxClipboardLocale->addItem("1,000.0");
+	boxClipboardLocale->addItem("1.000,0");
+	boxClipboardLocale->addItem("1 000,0");
+	
+    if (app->clipboardLocale().name() == QLocale::c().name())
+        boxClipboardLocale->setCurrentIndex(1);
+    else if (app->clipboardLocale().name() == QLocale(QLocale::German).name())
+        boxClipboardLocale->setCurrentIndex(2);
+    else if (app->clipboardLocale().name() == QLocale(QLocale::French).name())
+        boxClipboardLocale->setCurrentIndex(3);
+	
 	lblTranslationsPath->setText(tr("Translations"));
 	lblHelpPath->setText(tr("Help"));
 #ifdef SCRIPTING_PYTHON
@@ -1295,7 +1322,9 @@ void ConfigDialog::apply()
 	app->d_init_window_type = (ApplicationWindow::WindowType)boxInitWindow->currentIndex();
 	app->setMatrixUndoStackSize(undoStackSizeBox->value());
 	app->d_eol = (ApplicationWindow::EndLineChar)boxEndLine->currentIndex();
+#ifdef SCRIPTING_PYTHON
     app->enableCompletion(completionBox->isChecked());
+#endif
 
     app->d_note_line_numbers = lineNumbersBox->isChecked();
     foreach(MdiSubWindow *w, windows){
@@ -1323,7 +1352,6 @@ void ConfigDialog::apply()
     if (boxThousandsSeparator->isChecked())
         locale.setNumberOptions(QLocale::OmitGroupSeparator);
 
-    app->d_thousands_sep = !boxThousandsSeparator->isChecked();
     QLocale oldLocale = app->locale();
     app->setLocale(locale);
 
@@ -1339,9 +1367,57 @@ void ConfigDialog::apply()
             else if(w->isA("Matrix"))
                 ((Matrix *)w)->resetView();
         }
+		
+		switch (boxClipboardLocale->currentIndex()){
+        	case 0:
+            	app->setClipboardLocale(QLocale::system());
+        	break;
+        	case 1:
+            	app->setClipboardLocale(QLocale::c());
+        	break;
+        	case 2:
+            	app->setClipboardLocale(QLocale(QLocale::German));
+        	break;
+        	case 3:
+            	app->setClipboardLocale(QLocale(QLocale::French));
+        	break;
+    	}
+		
         app->modifiedProject();
     	QApplication::restoreOverrideCursor();
 	}
+	
+	// general page: file locations tab	
+	if (generalDialog->currentWidget() == appTabWidget &&
+		appTabWidget->currentWidget() == fileLocationsPage){
+		QString path = translationsPathLine->text();
+		if (path != app->d_translations_folder){
+			QFileInfo fi(path);
+			if (fi.exists() && fi.isDir()){
+				app->d_translations_folder = fi.absoluteFilePath();
+				app->createLanguagesList();
+				insertLanguagesList();
+			}
+		}
+	
+		path = helpPathLine->text() + "/index.html";
+		if (path != app->helpFilePath){
+			QFileInfo fi(path);
+			if (fi.exists() && fi.isFile())
+				app->helpFilePath = fi.absoluteFilePath();
+		}
+
+#ifdef SCRIPTING_PYTHON
+		path = pythonConfigDirLine->text();
+		if (path != app->d_python_config_folder){
+			QFileInfo fi(path);
+			if (fi.exists() && fi.isDir())
+				app->d_python_config_folder = fi.absoluteFilePath();
+		}
+#endif
+	}
+
+	
 	// general page: confirmations tab
 	app->d_inform_rename_table = boxPromptRenameTables->isChecked();
 	app->confirmCloseFolder = boxFolders->isChecked();
@@ -1628,7 +1704,11 @@ void ConfigDialog::chooseTranslationsFolder()
 
 	QFileInfo tfi(app->d_translations_folder);
 	QString dir = QFileDialog::getExistingDirectory(this, tr("Choose the location of the QtiPlot translations folder!"),
+#ifdef Q_CC_MSVC
+			tfi.dir().absolutePath(), 0);
+#else
 			tfi.dir().absolutePath(), !QFileDialog::ShowDirsOnly);
+#endif
 
 	if (!dir.isEmpty()){
 		app->d_translations_folder = dir;
@@ -1659,7 +1739,11 @@ void ConfigDialog::choosePythonConfigFolder()
 
 	QFileInfo tfi(app->d_python_config_folder);
 	QString dir = QFileDialog::getExistingDirectory(this, tr("Choose the location of the Python configuration files!"),
+#ifdef Q_CC_MSVC
+			tfi.dir().absolutePath(), 0);
+#else
 			tfi.dir().absolutePath(), !QFileDialog::ShowDirsOnly);
+#endif
 
 	if (!dir.isEmpty()){
 		app->d_python_config_folder = dir;
