@@ -377,12 +377,15 @@ QString Fit::legendInfo()
 	info += "Chi^2/doF = " + locale.toString(chi_2_dof, 'e', d_prec) + "\n";
 	info += tr("R^2") + " = " + locale.toString(rSquare(), 'g', d_prec) + "\n";
 
-	for (int i=0; i<d_p; i++){
+	for (int i = 0; i < d_p; i++){
 		info += d_param_names[i] + " = " + locale.toString(d_results[i], 'e', d_prec) + " +/- ";
 		if (d_scale_errors)
-			info += locale.toString(sqrt(chi_2_dof*gsl_matrix_get(covar, i, i)), 'e', d_prec) + "\n";
+			info += locale.toString(sqrt(chi_2_dof*gsl_matrix_get(covar, i, i)), 'e', d_prec);
 		else
-			info += locale.toString(sqrt(gsl_matrix_get(covar, i, i)), 'e', d_prec) + "\n";
+			info += locale.toString(sqrt(gsl_matrix_get(covar, i, i)), 'e', d_prec);
+		
+		if (i < d_p - 1)
+			info += "\n";
 	}
 	return info;
 }
@@ -795,12 +798,8 @@ void Fit::fit()
 
 	QApplication::setOverrideCursor(Qt::WaitCursor);
 
-	const char *function = d_formula.ascii();
-	QString names = d_param_names.join (",");
-	const char *parNames = names.ascii();
-
-	struct FitData d_data = {d_n, d_p, d_x, d_y, d_w, function, parNames};
-
+	struct FitData d_data = {d_n, d_p, d_x, d_y, d_w, this};
+	
 	int status, iterations = d_max_iterations;
 	if(d_solver == NelderMeadSimplex){
 		gsl_multimin_function f;
@@ -834,7 +833,7 @@ void Fit::fit()
 	}
 
 	generateFitCurve();
-
+	
 	ApplicationWindow *app = (ApplicationWindow *)parent();
 	if (app->writeFitResultsToLog)
 		app->updateLog(logFitInfo(iterations, status));
@@ -867,29 +866,21 @@ void Fit::generateFitCurve()
 	delete [] Y;
 }
 
-void Fit::insertFitFunctionCurve(const QString& name, double *x, double *y, int penWidth)
+FunctionCurve * Fit::insertFitFunctionCurve(const QString& name, double *x, double *y, int penWidth)
 {
-	QString formula = d_formula;
-	for (int j=0; j<d_p; j++){
-		QString parameter = QString::number(d_results[j], 'e', d_prec);
-		formula.replace(d_param_names[j], parameter);
-	}
-
-	formula = formula.replace("-+", "-").replace("+-", "-");
-	if (formula.startsWith ("--", Qt::CaseInsensitive))
-        formula = formula.right(formula.length() - 2);
-	formula.replace("(--", "(");
-	formula.replace("--", "+");
-	d_result_formula = formula;
-
 	QString title = d_output_graph->generateFunctionName(name);
 	FunctionCurve *c = new FunctionCurve(FunctionCurve::Normal, title);
 	c->setPen(QPen(ColorBox::color(d_curveColorIndex), penWidth));
 	c->setData(x, y, d_points);
 	c->setRange(d_x[0], d_x[d_n-1]);
-	c->setFormula(formula);
+	c->setFormula(d_formula);
+	
+	for (int j=0; j<d_p; j++)
+		c->setConstant(d_param_names[j], d_results[j]);	
+	
 	d_output_graph->insertPlotItem(c, Graph::Line);
 	d_output_graph->addFitCurve(c);
+	return c;
 }
 
 bool Fit::save(const QString& fileName)
@@ -953,7 +944,7 @@ bool Fit::load(const QString& fileName)
 
 void Fit::setParameterRange(int parIndex, double left, double right)
 {
-	if (parIndex < 0 || parIndex >= d_p)
+	if (!d_param_range_left || !d_param_range_right || parIndex < 0 || parIndex >= d_p)
 		return;
 	
 	d_param_range_left[parIndex] = left;
