@@ -777,7 +777,11 @@ void FitDialog::showFitPage()
 	int prec = boxPrecision->value();
     for (int i = 0; i<parameters; i++){
         QTableWidgetItem *it = new QTableWidgetItem(paramList[i]);
+#ifdef Q_CC_MSVC
+        it->setFlags(it->flags() & (~Qt::ItemIsEditable));
+#else
         it->setFlags(!Qt::ItemIsEditable);
+#endif
         it->setBackground(QBrush(Qt::lightGray));
         it->setForeground(QBrush(Qt::darkRed));
         QFont font = it->font();
@@ -809,7 +813,11 @@ void FitDialog::showFitPage()
         boxParams->showColumn(4);
 		for (int i = 0; i<boxParams->rowCount(); i++ ){
             QTableWidgetItem *it = new QTableWidgetItem();
+#ifdef Q_CC_MSVC
+            it->setFlags(it->flags() & (~Qt::ItemIsEditable));
+#else
             it->setFlags(!Qt::ItemIsEditable);
+#endif
             it->setBackground(QBrush(Qt::lightGray));
             boxParams->setItem(i, 4, it);
 
@@ -1088,8 +1096,16 @@ void FitDialog::accept()
 	QStringList parameters = QStringList();
 	MyParser parser;
 	bool error = false;
+#ifdef Q_CC_MSVC
+    QVarLengthArray<double> paramsInit(n), paramRangeLeft(n), paramRangeRight(n);
+#else
 	double paramsInit[n], paramRangeLeft[n], paramRangeRight[n];
+#endif
 	QString formula = boxFunction->text();
+	NonLinearFit *nlf = qobject_cast<NonLinearFit *>(d_current_fit);
+	if (nlf)
+		nlf->removeConstants();
+	
 	try {
 		if (!boxParams->isColumnHidden(4)){
 			int j = 0;
@@ -1104,7 +1120,9 @@ void FitDialog::accept()
 					j++;
 				} else {
 					double val = ((DoubleSpinBox*)boxParams->cellWidget(i, 2))->value();
-					formula.replace(boxParams->item(i, 0)->text(), QString::number(val, 'e', app->fit_output_precision));
+					QString constName = boxParams->item(i, 0)->text();
+					((NonLinearFit *)d_current_fit)->setConstant(constName, val);
+					parser.DefineConst(constName.ascii(), val);	
 				}
 			}
 		} else {
@@ -1132,20 +1150,30 @@ void FitDialog::accept()
 
 	if (!error){
 		if (d_current_fit->type() == Fit::BuiltIn)
+#ifdef Q_CC_MSVC
+			modifyGuesses (paramsInit.data());
+#else
 			modifyGuesses (paramsInit);
+#endif
 		if (d_current_fit->type() == Fit::User){
 			d_current_fit->setParametersList(parameters);
 			d_current_fit->setFormula(formula);
 		}
 
+#ifdef Q_CC_MSVC
+		d_current_fit->setInitialGuesses(paramsInit.data());
+#else
 		d_current_fit->setInitialGuesses(paramsInit);
+#endif
 
 		if (!d_current_fit->setDataFromCurve(curve, start, end) ||
 			!d_current_fit->setWeightingData ((Fit::WeightingMethod)boxWeighting->currentIndex(),
 					       tableNamesBox->currentText()+"_"+colNamesBox->currentText())) return;
 			
-		for (int i=0; i<n; i++)
-			d_current_fit->setParameterRange(i, paramRangeLeft[i], paramRangeRight[i]);
+		if (btnParamRange->isEnabled()){
+			for (int i=0; i<n; i++)
+				d_current_fit->setParameterRange(i, paramRangeLeft[i], paramRangeRight[i]);
+		}
 		
 		d_current_fit->setTolerance(eps);
 		d_current_fit->setOutputPrecision(app->fit_output_precision);
@@ -1182,15 +1210,24 @@ void FitDialog::modifyGuesses(double* initVal)
 	if (!d_current_fit)
 		return;
 
-	QString fitName = d_current_fit->objectName();
-	if (fitName == tr("ExpDecay1"))
-		initVal[1] = 1/initVal[1];
-	else if (fitName == tr("ExpGrowth"))
-		initVal[1] = -1/initVal[1];
-	else if (fitName == tr("ExpDecay2")){
+	ExponentialFit *ef = qobject_cast<ExponentialFit *>(d_current_fit);
+	if (ef){
+		if (ef->isExponentialGrowth())
+			initVal[1] = -1/initVal[1];
+		else 
+			initVal[1] = 1/initVal[1];
+		return;
+	}
+	
+	TwoExpFit *two_ef = qobject_cast<TwoExpFit *>(d_current_fit);
+	if (two_ef){
 		initVal[1] = 1/initVal[1];
 		initVal[3] = 1/initVal[3];
-	} else if (fitName == tr("ExpDecay3")){
+		return;
+	}
+	
+	ThreeExpFit *three_ef = qobject_cast<ThreeExpFit *>(d_current_fit);
+	if (three_ef){
 		initVal[1] = 1/initVal[1];
 		initVal[3] = 1/initVal[3];
 		initVal[5] = 1/initVal[5];
@@ -1440,20 +1477,36 @@ void FitDialog::updatePreview()
         return;
 
     int d_points = generatePointsBox->value();
+#ifdef Q_CC_MSVC
+    QVarLengthArray<double> X(d_points), Y(d_points);
+#else
     double X[d_points], Y[d_points];
+#endif
     int p = boxParams->rowCount();
+#ifdef Q_CC_MSVC
+    QVarLengthArray<double> parameters(p);
+#else
     double parameters[p];
+#endif
     for (int i=0; i<p; i++)
         parameters[i] = ((DoubleSpinBox*)boxParams->cellWidget(i, 2))->value();
     if (d_current_fit->type() == Fit::BuiltIn)
+#ifdef Q_CC_MSVC
+        modifyGuesses(parameters.data());
+#else
         modifyGuesses(parameters);
+#endif
 
     double x0 = boxFrom->value();
     double step = (boxTo->value() - x0)/(d_points - 1);
     for (int i=0; i<d_points; i++){
         double x = x0 + i*step;
         X[i] = x;
+#ifdef Q_CC_MSVC
+        Y[i] = d_current_fit->eval(parameters.data(), x);
+#else
         Y[i] = d_current_fit->eval(parameters, x);
+#endif
     }
 
 	if (!d_preview_curve){
@@ -1463,7 +1516,11 @@ void FitDialog::updatePreview()
 	}
 
     d_preview_curve->setPen(QPen(ColorBox::color(boxColor->currentIndex()), 1));
+#ifdef Q_CC_MSVC
+    d_preview_curve->setData(X.data(), Y.data(), d_points);
+#else
     d_preview_curve->setData(X, Y, d_points);
+#endif
     d_graph->replot();
 }
 
