@@ -169,54 +169,56 @@ void Matrix::setCoordinates(double xs, double xe, double ys, double ye)
 	emit modifiedWindow(this);
 }
 
-QString Matrix::saveToString(const QString &info, bool saveAsTemplate)
+void Matrix::save(const QString &fn, const QString &info, bool saveAsTemplate)
 {
-    bool notTemplate = !saveAsTemplate;
-	QString s = "<matrix>\n";
+	QFile f(fn);
+	if (!f.isOpen()){
+		if (!f.open(QIODevice::Append))
+			return;
+	}
+	bool notTemplate = !saveAsTemplate;
+
+	QTextStream t( &f );
+	t.setEncoding(QTextStream::UnicodeUTF8);
+	t << "<matrix>\n";
 	if (notTemplate)
-        s += QString(objectName()) + "\t";
-	s += QString::number(numRows())+"\t";
-	s += QString::number(numCols())+"\t";
+        t << QString(objectName()) + "\t";
+	t << QString::number(numRows())+"\t";
+	t << QString::number(numCols())+"\t";
 	if (notTemplate)
-        s += birthDate() + "\n";
-	s += info;
-	s += "ColWidth\t" + QString::number(d_column_width)+"\n";
-	s += "<formula>\n" + formula_str + "\n</formula>\n";
-	s += "TextFormat\t" + QString(txt_format) + "\t" + QString::number(num_precision) + "\n";
+        t << birthDate() + "\n";
+	t << info;
+	t << "ColWidth\t" + QString::number(d_column_width)+"\n";
+	t << "<formula>\n" + formula_str + "\n</formula>\n";
+	t << "TextFormat\t" + QString(txt_format) + "\t" + QString::number(num_precision) + "\n";
 	if (notTemplate)
-        s += "WindowLabel\t" + windowLabel() + "\t" + QString::number(captionPolicy()) + "\n";
-	s += "Coordinates\t" + QString::number(x_start,'g',15) + "\t" +QString::number(x_end,'g',15) + "\t";
-	s += QString::number(y_start,'g',15) + "\t" + QString::number(y_end,'g',15) + "\n";
-	s += "ViewType\t" + QString::number((int)d_view_type) + "\n";
-    s += "HeaderViewType\t" + QString::number((int)d_header_view_type) + "\n";
+        t << "WindowLabel\t" + windowLabel() + "\t" + QString::number(captionPolicy()) + "\n";
+	t << "Coordinates\t" + QString::number(x_start,'g',15) + "\t" +QString::number(x_end,'g',15) + "\t";
+	t << QString::number(y_start,'g',15) + "\t" + QString::number(y_end,'g',15) + "\n";
+	t << "ViewType\t" + QString::number((int)d_view_type) + "\n";
+    t << "HeaderViewType\t" + QString::number((int)d_header_view_type) + "\n";
 
 	if (d_color_map_type != Custom)
-		s += "ColorPolicy\t" + QString::number(d_color_map_type) + "\n";
+		t << "ColorPolicy\t" + QString::number(d_color_map_type) + "\n";
 	else {
-		s += "<ColorMap>\n";
-		s += "\t<Mode>" + QString::number(d_color_map.mode()) + "</Mode>\n";
-		s += "\t<MinColor>" + d_color_map.color1().name() + "</MinColor>\n";
-		s += "\t<MaxColor>" + d_color_map.color2().name() + "</MaxColor>\n";
+		t << "<ColorMap>\n";
+		t << "\t<Mode>" + QString::number(d_color_map.mode()) + "</Mode>\n";
+		t << "\t<MinColor>" + d_color_map.color1().name() + "</MinColor>\n";
+		t << "\t<MaxColor>" + d_color_map.color2().name() + "</MaxColor>\n";
 		QwtArray <double> colors = d_color_map.colorStops();
 		int stops = (int)colors.size();
-		s += "\t<ColorStops>" + QString::number(stops - 2) + "</ColorStops>\n";
+		t << "\t<ColorStops>" + QString::number(stops - 2) + "</ColorStops>\n";
 		for (int i = 1; i < stops - 1; i++){
-			s += "\t<Stop>" + QString::number(colors[i]) + "\t";
-			s += QColor(d_color_map.rgb(QwtDoubleInterval(0,1), colors[i])).name();
-			s += "</Stop>\n";
+			t << "\t<Stop>" + QString::number(colors[i]) + "\t";
+			t << QColor(d_color_map.rgb(QwtDoubleInterval(0,1), colors[i])).name();
+			t << "</Stop>\n";
 		}
-		s += "</ColorMap>\n";
+		t << "</ColorMap>\n";
 	}
 
     if (notTemplate)
-        s += d_matrix_model->saveToString();
-    s +="</matrix>\n";
-	return s;
-}
-
-QString Matrix::saveAsTemplate(const QString &info)
-{
-	return saveToString(info, true);
+        t << d_matrix_model->saveToString();
+    t <<"</matrix>\n";
 }
 
 void Matrix::restore(const QStringList &lst)
@@ -641,7 +643,7 @@ void Matrix::pasteSelection()
 		return;
 	}
 
-	QLocale locale = this->locale(); //Better use QLocale::system() ??
+	QLocale locale = applicationWindow()->clipboardLocale();
 	int cell = 0;
 	for(int i = 0; i < rows; i++){
 		QStringList cells = linesList[i].split("\t");
@@ -973,7 +975,7 @@ void Matrix::print(const QString& fileName)
 		}
 }
 
-void Matrix::exportVector(const QString& fileName, int res, bool color, bool keepAspect, QPrinter::PageSize pageSize)
+void Matrix::exportVector(const QString& fileName, int res, bool color)
 {
     if (d_view_type != ImageView)
         return;
@@ -998,42 +1000,12 @@ void Matrix::exportVector(const QString& fileName, int res, bool color, bool kee
 	else
 		printer.setColorMode(QPrinter::GrayScale);
 
+	printer.setOrientation(QPrinter::Portrait);
+
     int cols = numCols();
     int rows = numRows();
     QRect rect = QRect(0, 0, cols, rows);
-    if (pageSize == QPrinter::Custom)
-        printer.setPageSize(Graph::minPageSize(printer, rect));
-    else
-        printer.setPageSize(pageSize);
-
-    double aspect = (double)cols/(double)rows;
-	if (aspect < 1)
-		printer.setOrientation(QPrinter::Portrait);
-	else
-		printer.setOrientation(QPrinter::Landscape);
-
-    if (keepAspect){// export should preserve aspect ratio
-        double page_aspect = double(printer.width())/double(printer.height());
-        if (page_aspect > aspect){
-            int margin = (int) ((0.1/2.54)*printer.logicalDpiY()); // 1 mm margins
-            int height = printer.height() - 2*margin;
-            int width = int(height*aspect);
-            int x = (printer.width()- width)/2;
-            rect = QRect(x, margin, width, height);
-        } else if (aspect >= page_aspect){
-            int margin = (int) ((0.1/2.54)*printer.logicalDpiX()); // 1 mm margins
-            int width = printer.width() - 2*margin;
-            int height = int(width/aspect);
-            int y = (printer.height()- height)/2;
-            rect = QRect(margin, y, width, height);
-        }
-	} else {
-	    int x_margin = (int) ((0.1/2.54)*printer.logicalDpiX()); // 1 mm margins
-        int y_margin = (int) ((0.1/2.54)*printer.logicalDpiY()); // 1 mm margins
-        int width = printer.width() - 2*x_margin;
-        int height = printer.height() - 2*y_margin;
-        rect = QRect(x_margin, y_margin, width, height);
-	}
+    printer.setPaperSize(QSizeF(cols, rows), QPrinter::DevicePixel);
 
     QPainter paint(&printer);
     paint.drawImage(rect, d_matrix_model->renderImage());
@@ -1262,13 +1234,30 @@ void Matrix::importImage(const QString& fn)
 	if (buffer){
     	d_undo_stack->push(new MatrixSetImageCommand(d_matrix_model, image, d_view_type, 0,
 							numRows() - 1, 0, numCols() - 1, buffer, tr("Import Image") + " \"" + fn + "\""));
-        setWindowLabel(fn);
 		emit modifiedWindow(this);
 	} else if (ignoreUndo()){
 		d_matrix_model->setImage(image);
 		setViewType(ImageView, false);
 		displayImage(image);
-		setWindowLabel(fn);
+		emit modifiedWindow(this);
+	}
+	setWindowLabel(fn);
+}
+
+void Matrix::importImage(const QImage& image)
+{
+	if (image.isNull())
+        return;
+
+	double *buffer = d_matrix_model->dataCopy();
+	if (buffer){
+    	d_undo_stack->push(new MatrixSetImageCommand(d_matrix_model, image, d_view_type, 0,
+							numRows() - 1, 0, numCols() - 1, buffer, tr("Import Image")));
+		emit modifiedWindow(this);
+	} else if (ignoreUndo()){
+		d_matrix_model->setImage(image);
+		setViewType(ImageView, false);
+		displayImage(image);
 		emit modifiedWindow(this);
 	}
 }
@@ -1486,6 +1475,12 @@ double* Matrix::initWorkspace(int size)
 	return d_workspace;
 }
 
+QString Matrix::sizeToString()
+{
+	int size = d_matrix_model->rowCount() * d_matrix_model->columnCount();
+	return QString::number((sizeof(Matrix) + size*sizeof(double))/1024.0, 'f', 1) + " " + tr("kB");
+}
+
 Matrix::~Matrix()
 {
     delete d_undo_stack;
