@@ -99,10 +99,11 @@ public:
 	QImage image();
 	void displayImage(const QImage& image);
 	void importImage(const QString& fn);
+	void importImage(const QImage& image);
 	void exportRasterImage(const QString& fileName, int quality = 100);
 	void exportSVG(const QString& fileName);
 	void exportToFile(const QString& fileName);
-	void exportVector(const QString& fileName, int res = 0, bool color = true, bool keepAspect = true, QPrinter::PageSize pageSize = QPrinter::Custom);
+	void exportVector(const QString& fileName, int res = 0, bool color = true);
 
 	MatrixModel * matrixModel(){return d_matrix_model;};
     QUndoStack *undoStack(){return d_undo_stack;};
@@ -161,6 +162,8 @@ public:
 					bool simplifySpaces, const QString& commentString, ImportMode importAs = Overwrite,
 					const QLocale& l = QLocale(), int endLineChar = 0, int maxRows = -1);
 
+	virtual QString sizeToString();
+
 public slots:
 	void exportPDF(const QString& fileName);
 	//! Print the Matrix
@@ -224,10 +227,8 @@ public slots:
 	//! Load the matrix from a string list (i.e. lines from a project file)
 	void restore(const QStringList &l);
 	//! Format the matrix format in a string to save it in a template file
-	QString saveAsTemplate(const QString &info);
-
 	//! Return a string to save the matrix in a project file (\<matrix\> section)
-	QString saveToString(const QString &info, bool saveAsTemplate = false);
+	void save(const QString &, const QString &, bool saveAsTemplate = false);
 
 	// selection operations
 	//! Standard cut operation
@@ -291,7 +292,7 @@ public slots:
 	//! Tries to allocate memory for the workspace. Returns a NULL pointer if failure.
 	double *initWorkspace(int size);
 	void freeWorkspace(){free(d_workspace); d_workspace = NULL;};
-	
+
 	bool canCalculate(bool useMuParser = true);
 
 private:
