@@ -29,8 +29,6 @@
  *                                                                         *
  ***************************************************************************/
 #include "CanvasPicker.h"
-#include "ImageMarker.h"
-#include "LegendWidget.h"
 #include "ArrowMarker.h"
 #include "PlotCurve.h"
 #include "../ApplicationWindow.h"
@@ -57,7 +55,6 @@ bool CanvasPicker::eventFilter(QObject *object, QEvent *e)
 		return false;
 
 	Graph *g = plot();
-	QList<QwtPlotMarker *> images = g->imagesList();
 	QList<QwtPlotMarker *> lines = g->linesList();
 	switch(e->type())
 	{
@@ -85,11 +82,6 @@ bool CanvasPicker::eventFilter(QObject *object, QEvent *e)
 					return true;
 				}
 
-				if (me->button() == Qt::LeftButton && g->drawTextActive()){
-					drawTextMarker(me->pos());
-					return true;
-				}
-
 				if (!g->zoomOn() && selectMarker(me)){
 					if (me->button() == Qt::RightButton)
 						emit showMarkerPopupMenu();
@@ -108,9 +100,6 @@ bool CanvasPicker::eventFilter(QObject *object, QEvent *e)
 					if (lines.contains(g->selectedMarker())){
 						emit viewLineDialog();
 						return true;
-					} else if (images.contains(g->selectedMarker())){
-						emit viewImageDialog();
-						return true;
 					}
 				} else if (g->isPiePlot()){
                 	emit showPlotDialog(0);
@@ -193,11 +182,6 @@ bool CanvasPicker::eventFilter(QObject *object, QEvent *e)
 					emit viewLineDialog();
 					return true;
 				}
-				if (images.contains(selectedMarker) &&
-					(key == Qt::Key_Enter || key == Qt::Key_Return)){
-					emit viewImageDialog();
-					return true;
-				}
 			}
 			break;
 
@@ -215,27 +199,6 @@ void CanvasPicker::disableEditing()
 	}
 }
 
-void CanvasPicker::drawTextMarker(const QPoint& point)
-{
-	LegendWidget *aux = new LegendWidget(plot());
-	aux->move(point);
-
-	LegendWidget *l = plot()->addText(aux);
-	l->setText(tr("enter your text here"));
-	ApplicationWindow *app = plot()->multiLayer()->applicationWindow();
-	if (app){
-		l->setFrameStyle(app->legendFrameStyle);
-		l->setFont(app->plotLegendFont);
-		l->setTextColor(app->legendTextColor);
-		l->setBackgroundColor(app->legendBackground);
-	}
-    l->showTextDialog();
-
-    delete aux;
-	plot()->drawText(false);
-	emit drawTextOff();
-}
-
 void CanvasPicker::drawLineMarker(const QPoint& point, bool endArrow)
 {
 	Graph *g = plot();
@@ -264,15 +227,6 @@ bool CanvasPicker::selectMarker(const QMouseEvent *e)
 {
 	Graph *g = plot();
 	const QPoint point = e->pos();
-	QList<QwtPlotMarker *> images = g->imagesList();
-	foreach(QwtPlotMarker *i, images){
-		ImageMarker* m = (ImageMarker*)i;
-		if (m->rect().contains(point)) {
-			disableEditing();
-			plot()->setSelectedMarker(i, e->modifiers() & Qt::ShiftModifier);
-			return true;
-		}
-	}
 	QList<QwtPlotMarker *> lines = g->linesList();
 	foreach(QwtPlotMarker *i, lines){
 		ArrowMarker* mrkL = (ArrowMarker*)i;
