@@ -53,9 +53,8 @@ class QwtPlotCurve;
 class QwtPlotZoomer;
 class QwtPieCurve;
 class Table;
-class LegendWidget;
 class ArrowMarker;
-class ImageMarker;
+class ImageWidget;
 class TitlePicker;
 class ScalePicker;
 class CanvasPicker;
@@ -73,6 +72,9 @@ class VectorCurve;
 class BoxCurve;
 class QwtHistogram;
 class Grid;
+class TexWidget;
+class LegendWidget;
+class FrameWidget;
 
 //! Structure containing curve layout parameters
 typedef struct{
@@ -143,12 +145,16 @@ class Graph: public QwtPlot
 		PlotToolInterface* activeTool() const { return d_active_tool; }
 
 		QList <LegendWidget *> textsList();
-		LegendWidget *activeText(){return d_active_text;};
-		void setActiveText(LegendWidget *l){d_active_text = l;};
-		void select(LegendWidget *l, bool add = false);
+		LegendWidget *activeText();
+		void setActiveText(LegendWidget *l){d_active_enrichment = (FrameWidget *)l;};
+		void select(QWidget *l, bool add = false);
 
+		FrameWidget *activeEnrichment(){return d_active_enrichment;};
+		QList <FrameWidget *> enrichmentsList(){return d_enrichments;};
+
+		bool hasSeletedItems();
 		void deselect();
-		void deselect(LegendWidget *);
+		void deselect(QWidget *);
 
 		DataCurve* selectedCurveLabels();
         //! Used when restoring DataCurve curveID from a project file
@@ -189,8 +195,17 @@ class Graph: public QwtPlot
 
     	void updateCurveLabels();
 
+		TexWidget* addTexFormula(const QString& s, const QPixmap& pix);
+
+		FrameWidget* add(FrameWidget* fw, bool copy = true);
+		void remove(FrameWidget*);
+
+		QRect boundingRect();
+		void raiseEnrichements();
+
 	public slots:
 		void copy(Graph* g);
+		void copyCurves(Graph* g);
 
 		//! \name Pie Curves
 		//@{
@@ -216,6 +231,7 @@ class Graph: public QwtPlot
 		PlotCurve* insertCurve(Table* w, int xcol, const QString& name, int style);
 		PlotCurve* insertCurve(Table* w, const QString& xColName, const QString& yColName, int style, int startRow = 0, int endRow = -1);
 		void insertPlotItem(QwtPlotItem *i, int type);
+		void insertCurve(QwtPlotItem *c);
 
 		//! Shows/Hides a curve defined by its index.
 		void showCurve(int index, bool visible = true);
@@ -277,8 +293,7 @@ class Graph: public QwtPlot
 #ifdef EMF_OUTPUT
 		void exportEMF(const QString& fname);
 #endif
-		void exportVector(const QString& fileName, int res = 0, bool color = true,
-                        bool keepAspect = true, QPrinter::PageSize pageSize = QPrinter::Custom);
+		void exportVector(const QString& fileName, int res = 0, bool color = true);
 		void exportImage(const QString& fileName, int quality = 100, bool transparent = false);
 		//@}
 
@@ -317,6 +332,7 @@ class Graph: public QwtPlot
 				double stepBeforeBreak = 0.0, double stepAfterBreak = 0.0, int minTicksBeforeBreak = 4,
 				int minTicksAfterBreak = 4, bool log10AfterBreak = false, int breakWidth = 4, bool breakDecoration = true);
 		double axisStep(int axis){return d_user_step[axis];};
+		void setCanvasCoordinates(const QRectF&);
 
 		//! \name Curves Layout
 		//@{
@@ -362,28 +378,28 @@ class Graph: public QwtPlot
 		QString saveAxesFormulas();
 		//@}
 
-		//! \name Text Markers
+		//! \name Texts
 		//@{
-		void drawText(bool on);
-		bool drawTextActive(){return drawTextOn;};
 		LegendWidget* addText(LegendWidget*);
-		void remove(LegendWidget*);
-
 		//! Used when opening a project file
 		LegendWidget* insertText(const QStringList& list, int fileVersion);
 
 		LegendWidget* addTimeStamp();
-		void removeLegend();
 		void removeLegendItem(int index);
 		void insertLegend(const QStringList& lst, int fileVersion);
 
-		LegendWidget *legend(){return d_legend;};
 		LegendWidget* newLegend(const QString& text = QString());
-
 		//! Creates a new legend text using the curves titles
 		QString legendText();
 		//@}
 
+		//! \name Obsolete functions provided to keep existing Python scripts working
+		//@{
+		LegendWidget* legend();
+		void setLegend(const QString&);
+		void removeLegend();
+		//@}
+
 		//! \name Line Markers
 		//@{
 		ArrowMarker* addArrow(ArrowMarker* mrk);
@@ -402,14 +418,12 @@ class Graph: public QwtPlot
 
 		//! \name Image Markers
 		//@{
-		QList<QwtPlotMarker *> imagesList(){return d_images;};
-		ImageMarker* addImage(ImageMarker* mrk);
-		ImageMarker* addImage(const QString& fileName);
-		void remove(ImageMarker* im);
+		ImageWidget* addImage(ImageWidget* i);
+		ImageWidget* addImage(const QString& fileName);
+		ImageWidget* addImage(const QImage& image);
 
 		void insertImageMarker(const QStringList& lst, int fileVersion);
 		bool imageMarkerSelected();
-		void updateImageMarker(int x, int y, int width, int height);
 		//@}
 
 		//! \name Common to all Markers
@@ -527,7 +541,9 @@ class Graph: public QwtPlot
 
 		bool titleSelected();
 		void selectTitle(bool select = true);
-
+		//! Sets the title to an "almost empty" string: " ", thus keeping the QwtText object visible
+		void clearTitle();
+		//! Sets title to an empty string and hides the text label
 		void removeTitle();
 		void initTitle( bool on, const QFont& fnt);
 		//@}
@@ -547,10 +563,9 @@ class Graph: public QwtPlot
 		 */
 		bool enableRangeSelectors(const QObject *status_target=NULL, const char *status_slot="");
 
-		//! \name Border and Margin
+		//! \name Border and background
 		//@{
-		void setMargin (int d);
-		void setFrame(int width = 1, const QColor& color = QColor(Qt::black));
+		void setFrame(int width = 1, const QColor& color = Qt::black);
 		void setBackgroundColor(const QColor& color);
 		//@}
 
@@ -568,12 +583,11 @@ class Graph: public QwtPlot
 
 		//! \name User-defined Functions
 		//@{
-		void modifyFunctionCurve(int curve, int type, const QStringList &formulas, const QString &var, double start, double end, int points);
+		void modifyFunctionCurve(int curve, int type, const QStringList &formulas, const QString &var,
+			double start, double end, int points, const QMap<QString, double>& constants);
 		FunctionCurve* addFunction(const QStringList &formulas, double start, double end, int points = 100, const QString &var = "x", int type = 0, const QString& title = QString::null);
 		//! Used when reading from a project file with version < 0.9.5.
 		FunctionCurve* insertFunctionCurve(const QString& formula, int points, int fileVersion);
-		//! Used when reading from a project file with version >= 0.9.5.
-		void restoreFunction(const QStringList& lst);
 
 		//! Returns an unique function name
         QString generateFunctionName(const QString& name = tr("F"));
@@ -606,22 +620,24 @@ class Graph: public QwtPlot
 		void notifyChanges();
 
 		void updateSecondaryAxis(int axis);
-		void enableAutoscaling(bool yes){d_auto_scale = yes;};
+
+		bool isAutoscalingEnabled(){return d_auto_scale;};
+		void enableAutoscaling(bool on = true){d_auto_scale = on;};
 
 		bool autoscaleFonts(){return autoScaleFonts;};
-		void setAutoscaleFonts(bool yes){autoScaleFonts = yes;};
+		void setAutoscaleFonts(bool on = true){autoScaleFonts = on;};
 
 		static int obsoleteSymbolStyle(int type);
 		static QString penStyleName(Qt::PenStyle style);
 		static Qt::PenStyle getPenStyle(const QString& s);
 		static Qt::PenStyle getPenStyle(int style);
 		static void showPlotErrorMessage(QWidget *parent, const QStringList& emptyColumns);
-		static QPrinter::PageSize minPageSize(const QPrinter& printer, const QRect& r);
 
 		void showTitleContextMenu();
 		void copyTitle();
 		void cutTitle();
 
+		void clearAxisTitle();
 		void removeAxisTitle();
 		void cutAxisTitle();
 		void copyAxisTitle();
@@ -658,14 +674,11 @@ class Graph: public QwtPlot
 signals:
 		void selectedGraph (Graph*);
 		void closedGraph();
-		void drawTextOff();
 		void drawLineEnded(bool);
 		void cursorInfo(const QString&);
 		void showPlotDialog(int);
 		void createTable(const QString&,int,int,const QString&);
 
-		void viewImageDialog();
-		void viewTextDialog();
 		void viewLineDialog();
 		void viewTitleDialog();
 		void modifiedGraph();
@@ -686,8 +699,6 @@ signals:
         void enableTextEditor(Graph *);
 
 	private:
-		void insertCurve(QwtPlotItem *c);
-
         //! Finds bounding interval of the plot data.
         QwtDoubleInterval axisBoundingInterval(int axis);
         void deselectCurves();
@@ -718,13 +729,11 @@ signals:
 		bool d_antialiasing;
 		bool autoScaleFonts;
 		bool d_scale_on_print, d_print_cropmarks;
-		bool drawTextOn, drawLineOn, drawArrowOn, drawAxesBackbone;
+		bool drawLineOn, drawArrowOn, drawAxesBackbone;
 		//! Stores the step the user specified for the four scale. If step = 0.0, the step will be calculated automatically by the Qwt scale engine.
 		QVector<double> d_user_step;
 		//! Arrows/lines on plot
 		QList<QwtPlotMarker*> d_lines;
-		//! Images on plot
-		QList<QwtPlotMarker*> d_images;
 		//! Pointer to the currently selected line/image
 		QwtPlotMarker* d_selected_marker;
 		//! The markers selected for move/resize operations or NULL if none are selected.
@@ -732,14 +741,13 @@ signals:
 		//! The current curve selection, or NULL if none is active.
 		QPointer<RangeSelectorTool> d_range_selector;
 		//! The currently active tool, or NULL for default (pointer).
-		PlotToolInterface *d_active_tool;
+		PlotToolInterface *d_active_tool, *d_peak_fit_tool;
 		//! Pointer to the currently selected text/legend
-		LegendWidget *d_active_text;
-		//! Pointer to the current legend
-		LegendWidget *d_legend;
+		FrameWidget *d_active_enrichment;
         //! Flag indicating if the axes limits should be changed in order to show all data each time a curva data change occurs
 		bool d_auto_scale;
 		//! Axes tick lengths
 		int d_min_tick_length, d_maj_tick_length;
+		QList<FrameWidget*> d_enrichments;
 };
 #endif // GRAPH_H
