@@ -27,10 +27,12 @@
  *                                                                         *
  ***************************************************************************/
 #include "LegendWidget.h"
+#include "PlotCurve.h"
 #include "QwtPieCurve.h"
 #include "VectorCurve.h"
 #include "SelectionMoveResizer.h"
 #include "../ApplicationWindow.h"
+#include "../PenStyleBox.h"
 
 #include <QPainter>
 #include <QPolygon>
@@ -46,10 +48,13 @@
 
 #include <iostream>
 
-LegendWidget::LegendWidget(Graph *plot):QWidget(plot),
-	d_plot(plot),
-	d_frame (0),
-	d_angle(0)
+LegendWidget::LegendWidget(Graph *plot):FrameWidget(plot),
+d_angle(0),
+h_space(5),
+left_margin(10),
+top_margin(5),
+line_length(20),
+d_auto_update(false)
 {
 	setAttribute(Qt::WA_DeleteOnClose);
 
@@ -61,17 +66,7 @@ LegendWidget::LegendWidget(Graph *plot):QWidget(plot),
 	d_text->setBackgroundPen (QPen(Qt::NoPen));
 	d_text->setPaintAttribute(QwtText::PaintBackground);
 
-	h_space = 5;
-	left_margin = 10;
-	top_margin = 5;
-	line_length = 20;
-
-	QPoint pos = plot->canvas()->pos();
-	pos = QPoint(pos.x() + 10, pos.y() + 10);
-	move(pos);
-
-	connect (this, SIGNAL(showDialog()), plot, SIGNAL(viewTextDialog()));
-	connect (this, SIGNAL(showMenu()), plot, SIGNAL(showMarkerPopupMenu()));
+	move(plot->mapToParent(plot->canvas()->pos() + QPoint(10, 10)));
 	connect (this, SIGNAL(enableEditor()), plot, SLOT(enableTextEditor()));
 
 	setMouseTracking(true);
@@ -82,17 +77,13 @@ LegendWidget::LegendWidget(Graph *plot):QWidget(plot),
 void LegendWidget::paintEvent(QPaintEvent *e)
 {
 	const int symbolLineLength = line_length + symbolsMaxWidth();
-	int width, height;
-	QwtArray<long> heights = itemsHeight(0, symbolLineLength, width, height);
-	if (d_frame == Shadow)
-		resize(width + 5, height + 5);
-	else
-    	resize(width, height);
+	int width, height, textWidth, textHeight;
+	QwtArray<long> heights = itemsHeight(symbolLineLength, width, height, textWidth, textHeight);
+    resize(width, height);
 
-	QRect rect = QRect(0, 0, width - 1, height - 1);
     QPainter p(this);
-	drawFrame(&p, rect);
-	drawText(&p, rect, heights, symbolLineLength);
+	drawFrame(&p, rect());
+	drawText(&p, QRect(0, 0, textWidth, textHeight), heights, symbolLineLength);
 	e->accept();
 }
 
@@ -102,12 +93,11 @@ void LegendWidget::print(QPainter *painter, const QwtScaleMap map[QwtPlot::axisC
 	int y = map[QwtPlot::yLeft].transform(calculateYValue());
 
     const int symbolLineLength = line_length + symbolsMaxWidth();
-	int width, height;
-	QwtArray<long> heights = itemsHeight(y, symbolLineLength, width, height);
-
-	QRect rect = QRect(x, y, width, height);
-	drawFrame(painter, rect);
-	drawText(painter, rect, heights, symbolLineLength);
+	int width, height, textWidth, textHeight;
+	QwtArray<long> heights = itemsHeight(symbolLineLength, width, height, textWidth, textHeight);
+	
+	drawFrame(painter, QRect(x, y, width, height));
+	drawText(painter, QRect(x, y, textWidth, textHeight), heights, symbolLineLength);
 }
 
 void LegendWidget::setText(const QString& s)
@@ -115,22 +105,6 @@ void LegendWidget::setText(const QString& s)
 	d_text->setText(s);
 }
 
-void LegendWidget::setFrameStyle(int style)
-{
-	if (d_frame == style)
-		return;
-
-	d_frame = style;
-}
-
-void LegendWidget::setBackgroundColor(const QColor& c)
-{
-	if (d_text->backgroundBrush().color() == c)
-		return;
-
-	d_text->setBackgroundBrush(QBrush(c));
-}
-
 void LegendWidget::setTextColor(const QColor& c)
 {
 	if ( c == d_text->color() )
@@ -139,40 +113,6 @@ void LegendWidget::setTextColor(const QColor& c)
 	d_text->setColor(c);
 }
 
-void LegendWidget::updateCoordinates()
-{
-    d_x = calculateXValue();
-    d_y = calculateYValue();
-}
-
-void LegendWidget::setOriginCoord(double x, double y)
-{
-	QPoint pos(d_plot->transform(QwtPlot::xBottom, x), d_plot->transform(QwtPlot::yLeft, y));
-	pos = d_plot->canvas()->mapToParent(pos);
-	QWidget::move(pos);
-	
-	d_x = x;
-	d_y = y;
-}
-
-void LegendWidget::move(const QPoint& pos)
-{
-	QWidget::move(pos);
-	updateCoordinates();
-}
-
-double LegendWidget::calculateXValue()
-{
-	QPoint d_pos = d_plot->canvas()->mapFromParent(pos());
-	return d_plot->invTransform(QwtPlot::xBottom, d_pos.x());
-}
-
-double LegendWidget::calculateYValue()
-{
-	QPoint d_pos = d_plot->canvas()->mapFromParent(pos());
-	return d_plot->invTransform(QwtPlot::yLeft, d_pos.y());
-}
-
 void LegendWidget::setFont(const QFont& font)
 {
 	if ( font == d_text->font() )
@@ -181,27 +121,6 @@ void LegendWidget::setFont(const QFont& font)
 	d_text->setFont(font);
 }
 
-void LegendWidget::drawFrame(QPainter *p, const QRect& rect)
-{
-	p->save();
-	p->setPen(QPen(Qt::black, 1, Qt::SolidLine, Qt::SquareCap, Qt::MiterJoin));
-    p->fillRect (rect, d_text->backgroundBrush());
-
-	if (d_frame == Line)
-        QwtPainter::drawRect(p, rect);
-	else if (d_frame == Shadow) {
-		QRect shadow_right = QRect(rect.right() + 1, rect.y() + 5, 5, rect.height());
-		QRect shadow_bottom = QRect(rect.x() + 5, rect.bottom() + 1, rect.width(), 5);
-		p->setBrush(QBrush(Qt::black));
-		p->drawRect(shadow_right);
-		p->drawRect(shadow_bottom);
-
-		p->setBrush(d_text->backgroundBrush());
-		QwtPainter::drawRect(p,rect);
-	}
-	p->restore();
-}
-
 void LegendWidget::drawVector(PlotCurve *c, QPainter *p, int x, int y, int l)
 {
 	if (!c)
@@ -217,7 +136,7 @@ void LegendWidget::drawVector(PlotCurve *c, QPainter *p, int x, int y, int l)
 	p->setPen(pen);
 	p->drawLine(x, y, x + l, y);
 
-	p->translate(x+l, y);
+	p->translate(x + l, y);
 
 	double pi=4*atan(-1.0);
 	int headLength = v->headLength();
@@ -288,14 +207,35 @@ void LegendWidget::drawText(QPainter *p, const QRect& rect,
 	if (d_plot->antialiasing())
 		p->setRenderHints(QPainter::Antialiasing);
 
+	p->setRenderHint(QPainter::TextAntialiasing);
+
+	p->translate(rect.x(), rect.y());	
+	
+	int aux_a = d_angle;
+	if (aux_a >= 270){
+        aux_a -= 270;
+		p->translate(rect.height()*cos(aux_a*M_PI/180.0), 0.0);
+	} else if (aux_a >= 180){
+        aux_a -= 180;
+		p->translate(this->width(), rect.height()*cos(aux_a*M_PI/180.0));
+	} else if (aux_a > 90){
+        aux_a -= 90;
+		p->translate(rect.width()*sin(aux_a*M_PI/180.0), this->height());
+	}  else
+		p->translate(0.0, rect.width()*sin(d_angle*M_PI/180.0));
+	
+    p->rotate(-d_angle);
+	
 	int l = symbolLineLength;
 	QString text = d_text->text();
 	QStringList titles = text.split("\n", QString::KeepEmptyParts);
 
 	for (int i=0; i<(int)titles.count(); i++){
-        int w = rect.x() + left_margin;
+		int w = left_margin + d_frame_pen.width();
+		bool  curveSymbol = false;
 		QString s = titles[i];
 		while (s.contains("\\l(") || s.contains("\\p{")){
+			curveSymbol = true;
 			int pos = s.indexOf("\\l(", 0);
 			if (pos >= 0){
                 QwtText aux(parse(s.left(pos)));
@@ -342,7 +282,8 @@ void LegendWidget::drawText(QPainter *p, const QRect& rect,
 		}
 
 		if (!s.isEmpty()){
-			w += h_space;
+			if (curveSymbol)
+				w += h_space;
 			QwtText aux(parse(s));
 			aux.setFont(d_text->font());
 			aux.setColor(d_text->color());
@@ -354,7 +295,8 @@ void LegendWidget::drawText(QPainter *p, const QRect& rect,
 	p->restore();
 }
 
-QwtArray<long> LegendWidget::itemsHeight(int y, int symbolLineLength, int &width, int &height)
+QwtArray<long> LegendWidget::itemsHeight(int symbolLineLength, int &width, int &height, 
+							 int &textWidth, int &textHeight)
 {
 	QString text = d_text->text();
 	QStringList titles = text.split("\n", QString::KeepEmptyParts);
@@ -364,12 +306,14 @@ QwtArray<long> LegendWidget::itemsHeight(int y, int symbolLineLength, int &width
 	width = 0;
 	height = 0;
 	int maxL = 0;
-	int h = top_margin;
+	int h = top_margin + d_frame_pen.width();
 	for (int i=0; i<n; i++){
 		QString s = titles[i];
 		int textL = 0;
+		bool curveSymbol = false;
 		while (s.contains("\\l(") || s.contains("\\p{")){
 			int pos = s.indexOf("\\l(", 0);
+			curveSymbol = true;
 			if (pos >= 0){
                 QwtText aux(parse(s.left(pos)));
                 aux.setFont(d_text->font());
@@ -404,6 +348,8 @@ QwtArray<long> LegendWidget::itemsHeight(int y, int symbolLineLength, int &width
 		aux.setFont(d_text->font());
 		QSize size = aux.textSize();
 		textL += size.width();
+		if (curveSymbol)
+			textL += h_space;
 
 		if (textL > maxL)
 			maxL = textL;
@@ -411,13 +357,43 @@ QwtArray<long> LegendWidget::itemsHeight(int y, int symbolLineLength, int &width
 		int textH = size.height();
 		height += textH;
 
-		heights[i] = y + h + textH/2;
+		heights[i] = h + textH/2;
 		h += textH;
 	}
 
-	height += 2*top_margin;
-	width = 2*left_margin + maxL + h_space;
 
+	height += 2*top_margin;
+	width = 2*left_margin + maxL;
+	
+	int fw = 2*d_frame_pen.width();
+    height += fw;
+    width += fw;
+
+    textHeight = height;
+    textWidth = width;
+	
+    int aux_a = d_angle;	
+	if (aux_a > 270)
+		aux_a -= 270;
+    if (aux_a >= 180)
+        aux_a -= 180;
+    if (aux_a > 90)
+        aux_a -= 90;
+    	
+	double angle = aux_a*M_PI/180.0;
+	if ((d_angle >= 0 && d_angle <= 90) || (d_angle >= 180 && d_angle <= 270)){
+    	height = int(textWidth*sin(angle) + textHeight*cos(angle));
+    	width = int(textWidth*cos(angle) + textHeight*sin(angle));
+	} else {
+    	height = int(textWidth*cos(angle) + textHeight*sin(angle));
+    	width = int(textWidth*sin(angle) + textHeight*cos(angle));
+	}
+	
+	if (d_frame == Shadow){
+		width += d_shadow_width;
+		height += d_shadow_width;
+	}
+	
 	return heights;
 }
 
@@ -519,18 +495,6 @@ PlotCurve* LegendWidget::getCurve(const QString& s, int &point)
 	return curve;
 }
 
-void LegendWidget::mousePressEvent (QMouseEvent *)
-{
-	d_plot->activateGraph();
-	/*bool shiftPressed = e->modifiers() & Qt::ShiftModifier;
-	if (!shiftPressed)
-        d_plot->deselectMarker();
-	d_plot->select(this, shiftPressed);*/
-
-	d_plot->deselectMarker();
-	d_plot->select(this);
-}
-
 void LegendWidget::showTextEditor()
 {
     ApplicationWindow *app = d_plot->multiLayer()->applicationWindow();
@@ -549,6 +513,8 @@ void LegendWidget::clone(LegendWidget* t)
 {
 	d_frame = t->frameStyle();
 	d_angle = t->angle();
+	setFramePen(t->framePen());
+	d_auto_update = t->isAutoUpdateEnabled();
 
 	setTextColor(t->textColor());
 	setBackgroundColor(t->backgroundColor());
@@ -557,6 +523,93 @@ void LegendWidget::clone(LegendWidget* t)
 	setOriginCoord(t->xValue(), t->yValue());
 }
 
+QString LegendWidget::saveToString()
+{
+	QString s = "<Legend>\n";
+	s += FrameWidget::saveToString();
+	s += "<Text>\n" + d_text->text() + "\n</Text>\n";
+
+	QFont f = d_text->font();
+	s += "<Font>" + f.family() + "\t";
+	s += QString::number(f.pointSize())+"\t";
+	s += QString::number(f.weight())+"\t";
+	s += QString::number(f.italic())+"\t";
+	s += QString::number(f.underline())+"\t";
+	s += QString::number(f.strikeOut())+"</Font>\n";
+
+	s += "<TextColor>" + d_text->color().name()+"</TextColor>\n";
+	QColor bc = backgroundColor();
+	s += "<Background>" + bc.name() + "</Background>\n";
+	s += "<Alpha>" + QString::number(bc.alpha()) + "</Alpha>\n";
+	s += "<Angle>" + QString::number(d_angle) + "</Angle>\n";
+	s += "<AutoUpdate>" + QString::number(d_auto_update) + "</AutoUpdate>\n";
+	return s + "</Legend>\n";
+}
+
+void LegendWidget::restore(Graph *g, const QStringList& lst)
+{
+	QColor backgroundColor = Qt::white;
+	double x = 0.0, y = 0.0;
+	QStringList::const_iterator line;
+	LegendWidget *l = new LegendWidget(g);
+	for (line = lst.begin(); line != lst.end(); line++){
+        QString s = *line;
+        if (s.contains("<Frame>"))
+			l->setFrameStyle((s.remove("<Frame>").remove("</Frame>").toInt()));
+		else if (s.contains("<Color>"))
+			l->setFrameColor(QColor(s.remove("<Color>").remove("</Color>")));
+		else if (s.contains("<FrameWidth>"))
+			l->setFrameWidth(s.remove("<FrameWidth>").remove("</FrameWidth>").toInt());
+		else if (s.contains("<LineStyle>"))
+			l->setFrameLineStyle(PenStyleBox::penStyle(s.remove("<LineStyle>").remove("</LineStyle>").toInt()));
+		else if (s.contains("<x>"))
+			x = s.remove("<x>").remove("</x>").toDouble();
+		else if (s.contains("<y>"))
+			y = s.remove("<y>").remove("</y>").toDouble();
+		else if (s.contains("<Text>")){
+			QStringList txt;
+			while ( s != "</Text>" ){
+				s = *(++line);
+				txt << s;
+			}
+			txt.pop_back();
+			l->setText(txt.join("\n"));
+		} else if (s.contains("<Font>")){
+			QStringList lst = s.remove("<Font>").remove("</Font>").split("\t");
+			QFont f = QFont(lst[0], lst[1].toInt(), lst[2].toInt(), lst[3].toInt());
+			f.setUnderline(lst[4].toInt());
+			f.setStrikeOut(lst[5].toInt());
+			l->setFont(f);
+		} else if (s.contains("<TextColor>"))
+			l->setTextColor(QColor(s.remove("<TextColor>").remove("</TextColor>")));
+		else if (s.contains("<Background>"))
+			backgroundColor = QColor(s.remove("<Background>").remove("</Background>"));
+		else if (s.contains("<Alpha>"))
+			backgroundColor.setAlpha(s.remove("<Alpha>").remove("</Alpha>").toInt());
+		else if (s.contains("<Angle>"))
+			l->setAngle(s.remove("<Angle>").remove("</Angle>").toInt());
+		else if (s.contains("<AutoUpdate>"))
+			l->setAutoUpdate(s.remove("<AutoUpdate>").remove("</AutoUpdate>").toInt());
+	}
+	if (l){
+		l->setBackgroundColor(backgroundColor);
+		l->setOriginCoord(x, y);
+		g->add(l, false);
+	}
+}
+
+void LegendWidget::setAngle(int angle)
+{
+    if (d_angle == angle)
+        return;
+
+    d_angle = angle;
+	if (d_angle < 0)
+		d_angle += 360;
+	else if (d_angle >= 360)
+		d_angle -= 360;
+}
+
 LegendWidget::~LegendWidget()
 {
 	delete d_text;
