@@ -37,6 +37,7 @@
 #include <QPainter>
 #include <QPicture>
 #include <QClipboard>
+#include <QTextStream>
 
 #if QT_VERSION >= 0x040300
 	#include <QSvgGenerator>
@@ -50,6 +51,7 @@
 
 #include "MultiLayer.h"
 #include "LegendWidget.h"
+#include "Spectrogram.h"
 #include "SelectionMoveResizer.h"
 #include "../ApplicationWindow.h"
 
@@ -104,7 +106,7 @@ d_scale_layers(parent->autoResizeLayers)
 	hbox->addLayout(layerButtonsBox);
 	hbox->addStretch();
 
-	canvas = new QWidget();
+	d_canvas = new QWidget();
 
 	QWidget *mainWidget = new QWidget();
 	mainWidget->setAutoFillBackground(true);
@@ -112,7 +114,7 @@ d_scale_layers(parent->autoResizeLayers)
 
 	QVBoxLayout* layout = new QVBoxLayout(mainWidget);
 	layout->addLayout(hbox);
-	layout->addWidget(canvas, 1);
+	layout->addWidget(d_canvas, 1);
 	layout->setMargin(0);
 	layout->setSpacing(0);
 	setWidget(mainWidget);
@@ -121,8 +123,8 @@ d_scale_layers(parent->autoResizeLayers)
     int canvas_height = graph_height + top_margin + bottom_margin;
     setGeometry(QRect(0, 0, canvas_width, canvas_height + LayerButton::btnSize()));
 
-    canvas->resize(canvas_width, canvas_height);
-	canvas->installEventFilter(this);
+    d_canvas->resize(canvas_width, canvas_height);
+	d_canvas->installEventFilter(this);
 
 	QPalette pal = palette();
 	pal.setColor(QPalette::Window, QColor(Qt::white));
@@ -162,16 +164,17 @@ Graph* MultiLayer::addLayer(int x, int y, int width, int height)
 {
 	addLayerButton();
 	if (!width && !height){
-		width =	canvas->width() - left_margin - right_margin - (d_cols - 1)*colsSpace;
-		height = canvas->height() - top_margin - left_margin - (d_rows - 1)*rowsSpace;
+		width =	d_canvas->width() - left_margin - right_margin - (d_cols - 1)*colsSpace;
+		height = d_canvas->height() - top_margin - left_margin - (d_rows - 1)*rowsSpace;
 
 		int layers = graphsList.size();
 		x = left_margin + (layers % d_cols)*(width + colsSpace);
 	    y = top_margin + (layers / d_cols)*(height + rowsSpace);
 	}
 
-	Graph* g = new Graph(x, y, width, height, canvas);
+	Graph* g = new Graph(x, y, width, height, d_canvas);
     g->show();
+    g->raiseEnrichements();
 	graphsList.append(g);
 
 	active_graph = g;
@@ -181,7 +184,7 @@ Graph* MultiLayer::addLayer(int x, int y, int width, int height)
 
 void MultiLayer::adjustSize()
 {
-    canvas->resize(size().width(), size().height() - LayerButton::btnSize());
+    d_canvas->resize(size().width(), size().height() - LayerButton::btnSize());
 }
 
 void MultiLayer::activateGraph(LayerButton* button)
@@ -197,6 +200,7 @@ void MultiLayer::activateGraph(LayerButton* button)
 			active_graph = (Graph*) graphsList.at(i);
 			active_graph->setFocus();
 			active_graph->raise();//raise layer on top of the layers stack
+			active_graph->raiseEnrichements();
 			button->setOn(true);
 		}
 	}
@@ -214,6 +218,7 @@ void MultiLayer::setActiveLayer(Graph* g)
 		delete d_layers_selector;
 
 	active_graph->raise();//raise layer on top of the layers stack
+	active_graph->raiseEnrichements();
 
 	for(int i=0; i<graphsList.count(); i++){
 		Graph *gr = (Graph *)graphsList.at(i);
@@ -227,6 +232,14 @@ void MultiLayer::setActiveLayer(Graph* g)
 	}
 }
 
+QRect MultiLayer::canvasChildrenRect()
+{
+	QRect r = QRect();
+	foreach (Graph *g, graphsList)
+		r = r.united(g->boundingRect());
+	return r;
+}
+
 void MultiLayer::resizeLayers (QResizeEvent *re)
 {
 	if (!d_scale_layers || applicationWindow()->d_opening_file)
@@ -237,8 +250,9 @@ void MultiLayer::resizeLayers (QResizeEvent *re)
 
 	bool scaleLayerFonts = false;
 	if(!oldSize.isValid()){// The old size is invalid when maximizing a window (why?)
-        oldSize = QSize(canvas->childrenRect().width() + left_margin + right_margin,
-                        canvas->childrenRect().height() + top_margin + bottom_margin);
+		QRect r = canvasChildrenRect();
+        oldSize = QSize(r.width() + left_margin + right_margin,
+						r.height() + top_margin + bottom_margin);
 		scaleLayerFonts = true;
 	}
 
@@ -267,12 +281,12 @@ void MultiLayer::confirmRemoveLayer()
 					tr("&Yes"), tr("&No"), tr("&Cancel"),
 					0, 2) ){
 			case 0:
-				removeLayer();
+				removeLayer(active_graph);
 				arrangeLayers(true, false);
 				break;
 
 			case 1:
-				removeLayer();
+				removeLayer(active_graph);
 				break;
 
 			case 2:
@@ -280,50 +294,61 @@ void MultiLayer::confirmRemoveLayer()
 				break;
 		}
 	} else
-		removeLayer();
+		removeLayer(active_graph);
 }
 
-void MultiLayer::removeLayer()
+bool MultiLayer::removeActiveLayer()
 {
+    return removeLayer(active_graph);
+}
+
+bool MultiLayer::removeLayer(Graph *g)
+{
+    if (!g)
+        return false;
+
+    int index = graphsList.indexOf(g);
+    if (index < 0 || index > graphsList.size())
+        return false;
+
 	//remove corresponding button
-	foreach(LayerButton* btn, buttonsList){
-		if (btn->isOn()){
-			buttonsList.removeAll(btn);
-			btn->close(true);
-			break;
-		}
-	}
+	LayerButton* btn = buttonsList.at(index);
+	if (btn)
+        btn->close(true);
+    buttonsList.removeAt(index);
 
 	int i = 0;
-	foreach(LayerButton* btn, buttonsList)//update the texts of the buttons
-		btn->setText(QString::number(i + 1));
+	foreach(LayerButton* btn, buttonsList){
+		btn->setText(QString::number(++i));//update the texts of the buttons
+		btn->setOn(false);
+    }
 
-	if (active_graph->zoomOn() || active_graph->activeTool())
+	if (g->zoomOn() || g->activeTool())
 		emit setPointerCursor();
 
-	int index = graphsList.indexOf(active_graph);
 	graphsList.removeAt(index);
-	active_graph->close();
+	g->close();
 	if(index >= graphsList.count())
 		index--;
 
+	emit modifiedWindow(this);
+
 	if (graphsList.count() == 0){
-		active_graph = 0;
-		return;
+		active_graph = NULL;
+		return true;
 	}
 
-	active_graph=(Graph*) graphsList.at(index);
+	active_graph = (Graph*) graphsList.at(index);
 
-	for (i=0;i<(int)graphsList.count();i++){
-		Graph *gr=(Graph *)graphsList.at(i);
+	for (i=0; i<(int)graphsList.count(); i++){
+		Graph *gr = (Graph *)graphsList.at(i);
 		if (gr == active_graph){
 			LayerButton *button = (LayerButton *)buttonsList.at(i);
-			button->setOn(TRUE);
+			button->setOn(true);
 			break;
 		}
 	}
-
-	emit modifiedPlot();
+	return true;
 }
 
 void MultiLayer::setGraphGeometry(int x, int y, int w, int h)
@@ -339,10 +364,10 @@ void MultiLayer::setGraphGeometry(int x, int y, int w, int h)
 QSize MultiLayer::arrangeLayers(bool userSize)
 {
 	int layers = graphsList.size();
-	const QRect rect = canvas->geometry();
+	const QRect rect = d_canvas->geometry();
 
-	gsl_vector *xTopR = gsl_vector_calloc (layers);//ratio between top axis + title and canvas height
-	gsl_vector *xBottomR = gsl_vector_calloc (layers); //ratio between bottom axis and canvas height
+	gsl_vector *xTopR = gsl_vector_calloc (layers);//ratio between top axis + title and d_canvas height
+	gsl_vector *xBottomR = gsl_vector_calloc (layers); //ratio between bottom axis and d_canvas height
 	gsl_vector *yLeftR = gsl_vector_calloc (layers);
 	gsl_vector *yRightR = gsl_vector_calloc (layers);
 	gsl_vector *maxXTopHeight = gsl_vector_calloc (d_rows);//maximum top axis + title height in a row
@@ -353,7 +378,7 @@ QSize MultiLayer::arrangeLayers(bool userSize)
 	gsl_vector *X = gsl_vector_calloc (d_cols);
 
 	for (int i=0; i<layers; i++)
-	{//calculate scales/canvas dimensions reports for each layer and stores them in the above vectors
+	{//calculate scales/d_canvas dimensions reports for each layer and stores them in the above vectors
 		Graph *g = (Graph *)graphsList.at(i);
 		QwtPlotLayout *plotLayout = g->plotLayout();
 		QRect cRect = plotLayout->canvasRect();
@@ -390,7 +415,7 @@ QSize MultiLayer::arrangeLayers(bool userSize)
 			gsl_vector_set (yRightR, i, double(sRect.width())/cw);
 		}
 
-		//calculate max scales/canvas dimensions ratio for each line and column and stores them to vectors
+		//calculate max scales/d_canvas dimensions ratio for each line and column and stores them to vectors
 		int row = i / d_cols;
 		if (row >= d_rows )
 			row = d_rows - 1;
@@ -466,7 +491,7 @@ QSize MultiLayer::arrangeLayers(bool userSize)
 		//resizes and moves layers
 		Graph *g = (Graph *)graphsList.at(i);
 		bool autoscaleFonts = false;
-		if (!userSize){//When the user specifies the layer canvas size, the window is resized
+		if (!userSize){//When the user specifies the layer d_canvas size, the window is resized
 			//and the fonts must be scaled accordingly. If the size is calculated
 			//automatically we don't rescale the fonts in order to prevent problems
 			//with too small fonts when the user adds new layers or when removing layers
@@ -533,7 +558,7 @@ void MultiLayer::arrangeLayers(bool fit, bool userSize)
 	if (fit)
 		findBestLayout(d_rows, d_cols);
 
-	//the canvas sizes of all layers become equal only after several
+	//the d_canvas sizes of all layers become equal only after several
 	//resize iterations, due to the way Qwt handles the plot layout
 	int iterations = 0;
 	QSize size = arrangeLayers(userSize);
@@ -546,9 +571,9 @@ void MultiLayer::arrangeLayers(bool fit, bool userSize)
 
 	if (userSize){//resize window
 		this->showNormal();
-		QSize size = canvas->childrenRect().size();
-		this->resize(canvas->x() + size.width() + left_margin + 2*right_margin,
-					canvas->y() + size.height() + bottom_margin + 2*LayerButton::btnSize());
+		QSize size = d_canvas->childrenRect().size();
+		this->resize(d_canvas->x() + size.width() + left_margin + 2*right_margin,
+					d_canvas->y() + size.height() + bottom_margin + 2*LayerButton::btnSize());
 	}
 
 	emit modifiedPlot();
@@ -569,7 +594,7 @@ void MultiLayer::setRows(int r)
 
 QPixmap MultiLayer::canvasPixmap()
 {
-    QPixmap pic(canvas->size());
+    QPixmap pic(d_canvas->size());
     pic.fill();
     QPainter p(&pic);
 	foreach (Graph *g, graphsList)
@@ -639,7 +664,7 @@ void MultiLayer::exportPDF(const QString& fname)
 	exportVector(fname);
 }
 
-void MultiLayer::exportVector(const QString& fileName, int res, bool color, bool keepAspect, QPrinter::PageSize pageSize)
+void MultiLayer::exportVector(const QString& fileName, int, bool color)
 {
 	if ( fileName.isEmpty() ){
 		QMessageBox::critical(this, tr("QtiPlot - Error"),
@@ -662,64 +687,24 @@ void MultiLayer::exportVector(const QString& fileName, int res, bool color, bool
 	//if (res) //only printing with screen resolution works correctly for the moment
 		//printer.setResolution(res);
 
-	QRect canvasRect = canvas->rect();
-    if (pageSize == QPrinter::Custom)
-        printer.setPageSize(Graph::minPageSize(printer, canvasRect));
-    else
-        printer.setPageSize(pageSize);
-
-	double canvas_aspect = double(canvasRect.width())/double(canvasRect.height());
-	if (canvas_aspect < 1)
-		printer.setOrientation(QPrinter::Portrait);
-	else
-		printer.setOrientation(QPrinter::Landscape);
-
 	if (color)
 		printer.setColorMode(QPrinter::Color);
 	else
 		printer.setColorMode(QPrinter::GrayScale);
 
-    double x_margin = 0, y_margin = 0, width = 0, height = 0;
-    if (keepAspect){// export should preserve plot aspect ratio
-        double page_aspect = double(printer.width())/double(printer.height());
-        if (page_aspect > canvas_aspect){
-            y_margin = (0.1/2.54)*printer.logicalDpiY(); // 1 mm margins
-            height = printer.height() - 2*y_margin;
-            width = height*canvas_aspect;
-            x_margin = 0.5*(printer.width() - width);
-        } else {
-            x_margin = (0.1/2.54)*printer.logicalDpiX(); // 1 mm margins
-            width = printer.width() - 2*x_margin;
-            height = width/canvas_aspect;
-            y_margin = 0.5*(printer.height() - height);
-        }
-	} else {
-	    x_margin = (0.1/2.54)*printer.logicalDpiX(); // 1 mm margins
-        y_margin = (0.1/2.54)*printer.logicalDpiY(); // 1 mm margins
-        width = printer.width() - 2*x_margin;
-        height = printer.height() - 2*y_margin;
-	}
-
-    double scaleFactorX = width/(double)canvasRect.width();
-    double scaleFactorY = height/(double)canvasRect.height();
-
-    QPainter paint(&printer);
-	foreach (Graph *g, graphsList){
-        QPoint pos = g->pos();
-        pos = QPoint(qRound(x_margin + pos.x()*scaleFactorX), qRound(y_margin + pos.y()*scaleFactorY));
-
-        int layer_width = qRound(g->frameGeometry().width()*scaleFactorX);
-        int layer_height = qRound(g->frameGeometry().height()*scaleFactorY);
-
-        g->print(&paint, QRect(pos, QSize(layer_width, layer_height)));
-    }
+	printer.setOrientation(QPrinter::Portrait);
+    printer.setPaperSize(QSizeF(d_canvas->width(), d_canvas->height()), QPrinter::DevicePixel);
+    
+	QPainter paint(&printer);
+    foreach (Graph *g, graphsList)
+        g->print(&paint, g->geometry());
 }
 
 void MultiLayer::exportSVG(const QString& fname)
 {
 	QSvgGenerator generator;
 	generator.setFileName(fname);
-	generator.setSize(canvas->size());
+	generator.setSize(d_canvas->size());
 
 	QPainter p(&generator);
 	foreach (Graph *g, graphsList)
@@ -761,7 +746,11 @@ void MultiLayer::print()
 	QPrinter printer;
 	printer.setColorMode (QPrinter::Color);
 	printer.setFullPage(true);
-    QRect canvasRect = canvas->rect();
+#ifdef Q_OS_LINUX
+	printer.setOutputFileName(objectName());
+#endif
+
+    QRect canvasRect = d_canvas->rect();
     double aspect = double(canvasRect.width())/double(canvasRect.height());
     if (aspect < 1)
         printer.setOrientation(QPrinter::Portrait);
@@ -770,6 +759,16 @@ void MultiLayer::print()
 
     QPrintDialog printDialog(&printer, applicationWindow());
     if (printDialog.exec() == QDialog::Accepted){
+	#ifdef Q_OS_LINUX
+		if (printDialog.enabledOptions() & QAbstractPrintDialog::PrintToFile){
+			QString fn = printer.outputFileName();
+			if (printer.outputFormat() == QPrinter::PostScriptFormat && !fn.contains(".ps"))
+				printer.setOutputFileName(fn + ".ps");
+			else if (printer.outputFormat() == QPrinter::PdfFormat && !fn.contains(".pdf"))
+				printer.setOutputFileName(fn + ".pdf");
+		}
+	#endif
+
 		QPainter paint(&printer);
 		printAllLayers(&paint);
 		paint.end();
@@ -783,7 +782,7 @@ void MultiLayer::printAllLayers(QPainter *painter)
 
 	QPrinter *printer = (QPrinter *)painter->device();
 	QRect paperRect = ((QPrinter *)painter->device())->paperRect();
-	QRect canvasRect = canvas->rect();
+	QRect canvasRect = d_canvas->rect();
 	QRect pageRect = printer->pageRect();
 	QRect cr = canvasRect; // cropmarks rectangle
 
@@ -841,7 +840,7 @@ void MultiLayer::setFonts(const QFont& titleFnt, const QFont& scaleFnt,
 	foreach (Graph *g, graphsList){
 		QwtText text = g->title();
   	    text.setFont(titleFnt);
-  	    ((QwtPlot *)g)->setTitle(text);
+  	    g->setTitle(text);
 
 		for (int j= 0; j<QwtPlot::axisCnt; j++){
 			g->setAxisFont(j, numbersFnt);
@@ -862,7 +861,6 @@ void MultiLayer::setFonts(const QFont& titleFnt, const QFont& scaleFnt,
 void MultiLayer::connectLayer(Graph *g)
 {
 	connect (g,SIGNAL(drawLineEnded(bool)), this, SIGNAL(drawLineEnded(bool)));
-	connect (g,SIGNAL(drawTextOff()),this,SIGNAL(drawTextOff()));
 	connect (g,SIGNAL(showPlotDialog(int)),this,SIGNAL(showPlotDialog(int)));
 	connect (g,SIGNAL(createTable(const QString&,int,int,const QString&)),
 			this,SIGNAL(createTable(const QString&,int,int,const QString&)));
@@ -874,34 +872,33 @@ void MultiLayer::connectLayer(Graph *g)
 		connect (g,SIGNAL(showMarkerPopupMenu()),this,SIGNAL(showMarkerPopupMenu()));
 	connect (g,SIGNAL(showCurveContextMenu(QwtPlotCurve *)),this,SIGNAL(showCurveContextMenu(QwtPlotCurve *)));
 	connect (g,SIGNAL(cursorInfo(const QString&)),this,SIGNAL(cursorInfo(const QString&)));
-	connect (g,SIGNAL(viewImageDialog()),this,SIGNAL(showImageDialog()));
 	connect (g,SIGNAL(viewTitleDialog()),this,SIGNAL(viewTitleDialog()));
 	connect (g,SIGNAL(modifiedGraph()),this,SIGNAL(modifiedPlot()));
+	connect (g,SIGNAL(modifiedGraph()),this,SLOT(notifyChanges()));
 	connect (g,SIGNAL(selectedGraph(Graph*)),this, SLOT(setActiveLayer(Graph*)));
-	connect (g,SIGNAL(viewTextDialog()),this,SIGNAL(showTextDialog()));
 	connect (g,SIGNAL(currentFontChanged(const QFont&)), this, SIGNAL(currentFontChanged(const QFont&)));
     connect (g,SIGNAL(enableTextEditor(Graph *)), this, SIGNAL(enableTextEditor(Graph *)));
 }
 
 bool MultiLayer::eventFilter(QObject *object, QEvent *e)
 {
-	if(e->type() == QEvent::Resize && object == (QObject *)canvas){
-		canvas->setUpdatesEnabled(false);
+	if(e->type() == QEvent::Resize && object == (QObject *)d_canvas){
+		d_canvas->setUpdatesEnabled(false);
 		resizeLayers((QResizeEvent *)e);
-		canvas->setUpdatesEnabled(true);
-	} else if (e->type() == QEvent::MouseButtonPress && object == (QObject *)canvas){
+		d_canvas->setUpdatesEnabled(true);
+	} else if (e->type() == QEvent::MouseButtonPress && object == (QObject *)d_canvas){
 	    const QMouseEvent *me = (const QMouseEvent *)e;
 	    if (me->button() == Qt::RightButton)
             return QMdiSubWindow::eventFilter(object, e);
 
-        QPoint pos = canvas->mapFromParent(me->pos());
+        QPoint pos = d_canvas->mapFromParent(me->pos());
         // iterate backwards, so layers on top are preferred for selection
         QList<Graph*>::iterator i = graphsList.end();
         while (i != graphsList.begin()) {
             --i;
             Graph *g = *i;
-            if (g->activeText() || g->titleSelected() || g->selectedScale()){
-                g->deselect();
+            if (g->hasSeletedItems()){
+                //g->deselect();
                 return true;
             }
 
@@ -925,8 +922,15 @@ bool MultiLayer::eventFilter(QObject *object, QEvent *e)
                 return true;
             }
         }
-        if (d_layers_selector)
+        if (d_layers_selector){
+			foreach(Graph *g, graphsList){
+				if (d_layers_selector->contains((QWidget *)g)){
+					g->raiseEnrichements();
+					break;
+				}
+			}
             delete d_layers_selector;
+		}
 	}
 
 	return MdiSubWindow::eventFilter(object, e);
@@ -1021,35 +1025,38 @@ bool MultiLayer::isEmpty ()
 		return false;
 }
 
-QString MultiLayer::saveToString(const QString& geometry, bool saveAsTemplate)
+void MultiLayer::save(const QString &fn, const QString &geometry, bool saveAsTemplate)
 {
+	QFile f(fn);
+	if (!f.isOpen()){
+		if (!f.open(QIODevice::Append))
+			return;
+	}
+	QTextStream t( &f );
+	t.setEncoding(QTextStream::UnicodeUTF8);
+	t << "<multiLayer>\n";
+
     bool notTemplate = !saveAsTemplate;
-	QString s="<multiLayer>\n";
 	if (notTemplate)
-        s+=QString(objectName())+"\t";
-	s+=QString::number(d_cols)+"\t";
-	s+=QString::number(d_rows)+"\t";
+        t << QString(objectName())+"\t";
+	t << QString::number(d_cols)+"\t";
+	t << QString::number(d_rows)+"\t";
 	if (notTemplate)
-        s+=birthDate()+"\n";
-	s+=geometry;
+        t << birthDate()+"\n";
+	t << geometry;
 	if (notTemplate)
-        s+="WindowLabel\t" + windowLabel() + "\t" + QString::number(captionPolicy()) + "\n";
-	s+="Margins\t"+QString::number(left_margin)+"\t"+QString::number(right_margin)+"\t"+
+        t << "WindowLabel\t" + windowLabel() + "\t" + QString::number(captionPolicy()) + "\n";
+	t << "Margins\t"+QString::number(left_margin)+"\t"+QString::number(right_margin)+"\t"+
 		QString::number(top_margin)+"\t"+QString::number(bottom_margin)+"\n";
-	s+="Spacing\t"+QString::number(rowsSpace)+"\t"+QString::number(colsSpace)+"\n";
-	s+="LayerCanvasSize\t"+QString::number(l_canvas_width)+"\t"+QString::number(l_canvas_height)+"\n";
-	s+="Alignement\t"+QString::number(hor_align)+"\t"+QString::number(vert_align)+"\n";
+	t << "Spacing\t"+QString::number(rowsSpace)+"\t"+QString::number(colsSpace)+"\n";
+	t << "LayerCanvasSize\t"+QString::number(l_canvas_width)+"\t"+QString::number(l_canvas_height)+"\n";
+	t << "Alignement\t"+QString::number(hor_align)+"\t"+QString::number(vert_align)+"\n";
 
 	for (int i=0; i<(int)graphsList.count(); i++){
 		Graph* ag=(Graph*)graphsList.at(i);
-		s += ag->saveToString(saveAsTemplate);
+		t << ag->saveToString(saveAsTemplate);
 	}
-	return s+"</multiLayer>\n";
-}
-
-QString MultiLayer::saveAsTemplate(const QString& geometryInfo)
-{
-	return saveToString(geometryInfo, true);
+	t << "</multiLayer>\n";
 }
 
 void MultiLayer::setMargins (int lm, int rm, int tm, int bm)
@@ -1133,7 +1140,7 @@ void MultiLayer::setNumLayers(int n)
 			addLayer();
 	}
 
-	emit modifiedPlot();
+	emit modifiedWindow(this);
 }
 
 void MultiLayer::copy(MultiLayer* ml)
@@ -1154,16 +1161,6 @@ void MultiLayer::copy(MultiLayer* ml)
 	show();
 }
 
-bool MultiLayer::focusNextPrevChild ( bool next )
-{
-	return false;
-
-	if (!active_graph)
-		return true;
-
-	return active_graph->focusNextPrevChild(next);
-}
-
 bool MultiLayer::swapLayers(int src, int dest)
 {
 	Graph *layerSrc = layer(src);
@@ -1183,3 +1180,46 @@ bool MultiLayer::swapLayers(int src, int dest)
 	emit modifiedPlot();
 	return true;
 }
+
+QString MultiLayer::sizeToString()
+{
+	int layers = graphsList.size();
+	int size = sizeof(MultiLayer) + layers*sizeof(Graph);
+	foreach(Graph *g, graphsList){
+		QList<QwtPlotItem *> items = g->curvesList();
+		foreach(QwtPlotItem *i, items){
+			if (i->rtti() == QwtPlotItem::Rtti_PlotSpectrogram){
+            	Spectrogram *sp = (Spectrogram *)i;
+				int cells = sp->matrix()->numRows() * sp->matrix()->numCols();
+            	size += cells*sizeof(double);
+        	} else
+				size += ((QwtPlotCurve *)i)->dataSize()*sizeof(double);
+		}
+	}
+	return QString::number((double)size/1024.0, 'f', 1) + " " + tr("kB");
+}
+
+Graph* MultiLayer::layerAt(const QPoint& pos)
+{
+    foreach(Graph *g, graphsList){
+		if (g->geometry().contains(pos))
+            return g;
+	}
+	return NULL;
+}
+
+bool MultiLayer::hasSelectedLayers()
+{
+    if (d_layers_selector)
+        return true;
+    return false;
+}
+
+MultiLayer::~MultiLayer()
+{
+	if(d_layers_selector)
+        d_layers_selector->setParent(NULL);
+
+	foreach(Graph *g, graphsList)
+        delete g;
+}
