@@ -44,6 +44,7 @@
 #include "../../ColorMapEditor.h"
 #include "../../DoubleSpinBox.h"
 #include "../../Folder.h"
+#include "../../PenStyleBox.h"
 
 #include <QTreeWidget>
 #include <QLineEdit>
@@ -74,6 +75,7 @@ PlotDialog::PlotDialog(bool showExtended, QWidget* parent, Qt::WFlags fl )
 	setWindowTitle( tr( "QtiPlot - Plot details" ) );
 	setModal(true);
 	setSizeGripEnabled(true);
+    setAttribute(Qt::WA_DeleteOnClose);
 
 	listBox = new QTreeWidget();
     listBox->setColumnCount(1);
@@ -265,7 +267,7 @@ void PlotDialog::changePlotType(int plotType)
 		VectorCurve *v = (VectorCurve*)item->plotItem();
 		if (plotType)
 			v->setVectorStyle(VectorCurve::XYAM);
-		else 
+		else
 			v->setVectorStyle(VectorCurve::XYXY);
 		customVectorsPage(plotType);
 	} else {
@@ -360,52 +362,80 @@ void PlotDialog::initLayerPage()
     boxBkgLayout->addWidget( new QLabel(tr( "Width" )), 2, 2);
     boxBorderWidth = new QSpinBox();
     boxBkgLayout->addWidget( boxBorderWidth, 2, 3);
-    boxBkgLayout->setRowStretch( 4, 1 );
 
-    QGroupBox * box4 = new QGroupBox(QString());
-    QGridLayout * box4Layout = new QGridLayout( box4 );
+	boxAntialiasing = new QCheckBox(tr("Antialiasing"));
+    boxBkgLayout->addWidget( boxAntialiasing, 3, 0);
 
-    box4Layout->addWidget( new QLabel(tr( "Margin" )), 0, 0 );
-    boxMargin = new QSpinBox();
+	boxBkgLayout->addWidget( new QLabel(tr( "Margin" )), 3, 2);
+	boxMargin = new QSpinBox();
     boxMargin->setRange( 0, 1000 );
     boxMargin->setSingleStep(5);
-    box4Layout->addWidget( boxMargin, 0, 1 );
+    boxBkgLayout->addWidget( boxMargin, 3, 3);
 
-    boxAntialiasing = new QCheckBox(tr("Antialiasing"));
-    box4Layout->addWidget( boxAntialiasing, 1, 1 );
+	boxBkgLayout->setRowStretch(4, 1);
 
-    boxAll = new QCheckBox(tr("Apply to all layers"));
-    box4Layout->addWidget( boxAll, 2, 1 );
-    box4Layout->setRowStretch( 3, 1 );
+    QVBoxLayout *vl = new QVBoxLayout();
+
+    layerDefaultBtn = new QPushButton(tr("Set As &Default"));
+    connect(layerDefaultBtn, SIGNAL(clicked()), this, SLOT(setLayerDefaultValues()));
+	vl->addWidget(layerDefaultBtn);
+
+	QLabel *l = new QLabel(tr("Apply &to..."));
+	vl->addWidget(l);
+
+	backgroundApplyToBox = new QComboBox();
+	backgroundApplyToBox->insertItem(tr("Layer"));
+    backgroundApplyToBox->insertItem(tr("Window"));
+    backgroundApplyToBox->insertItem(tr("All Windows"));
+	vl->addWidget(backgroundApplyToBox);
+	vl->addStretch();
+
+	l->setBuddy(backgroundApplyToBox);
 
     QHBoxLayout * hl = new QHBoxLayout( layerPage );
     hl->addWidget(boxBkg);
-    hl->addWidget(box4);
+    hl->addLayout(vl);
 
     privateTabWidget->addTab(layerPage, tr("Layer"));
 
 	connect(boxBackgroundTransparency, SIGNAL(valueChanged(int)), this, SLOT(updateBackgroundTransparency(int)));
 	connect(boxCanvasTransparency, SIGNAL(valueChanged(int)), this, SLOT(updateCanvasTransparency(int)));
-	connect(boxAntialiasing, SIGNAL(toggled(bool)), this, SLOT(updateAntialiasing(bool)));
-	connect(boxMargin, SIGNAL(valueChanged (int)), this, SLOT(changeMargin(int)));
-	connect(boxBorderColor, SIGNAL(colorChanged()), this, SLOT(pickBorderColor()));
-	connect(boxBackgroundColor, SIGNAL(colorChanged()), this, SLOT(pickBackgroundColor()));
-	connect(boxCanvasColor, SIGNAL(colorChanged()), this, SLOT(pickCanvasColor()));
-	connect(boxBorderWidth,SIGNAL(valueChanged (int)), this, SLOT(updateBorder(int)));
+	connect(boxAntialiasing, SIGNAL(toggled(bool)), this, SLOT(applyLayerFormat()));
+	connect(boxMargin, SIGNAL(valueChanged (int)), this, SLOT(applyLayerFormat()));
+	connect(boxBorderColor, SIGNAL(colorChanged()), this, SLOT(applyLayerFormat()));
+	connect(boxBackgroundColor, SIGNAL(colorChanged()), this, SLOT(applyLayerFormat()));
+	connect(boxCanvasColor, SIGNAL(colorChanged()), this, SLOT(applyLayerFormat()));
+	connect(boxBorderWidth, SIGNAL(valueChanged (int)), this, SLOT(applyLayerFormat()));
 }
 
 void PlotDialog::initLayerGeometryPage()
 {
     layerGeometryPage = new QWidget();
 
-	QGroupBox *gb1 = new QGroupBox(tr("Origin"));
-	boxX = new QSpinBox();
-	boxX->setRange(0, 2000);
-	boxX->setSuffix(tr(" pixels"));
+	ApplicationWindow *app = (ApplicationWindow *)parent();
+	QLocale locale = QLocale();
+	if (app)
+		locale = app->locale();
 
-	boxY = new QSpinBox();
-	boxY->setRange(0, 2000);
-	boxY->setSuffix(tr(" pixels"));
+	unitBox = new QComboBox();
+	unitBox->insertItem(tr("inch"));
+	unitBox->insertItem(tr("mm"));
+	unitBox->insertItem(tr("cm"));
+	unitBox->insertItem(tr("point"));
+	unitBox->insertItem(tr("pixel"));
+
+	QBoxLayout *bl1 = new QBoxLayout (QBoxLayout::LeftToRight);
+	bl1->addWidget(new QLabel(tr( "Unit" )));
+	bl1->addWidget(unitBox);
+
+	QGroupBox *gb1 = new QGroupBox(tr("Origin"));
+	boxX = new DoubleSpinBox();
+	boxX->setLocale(locale);
+	boxX->setDecimals(6);
+
+	boxY = new DoubleSpinBox();
+	boxY->setLocale(locale);
+	boxY->setDecimals(6);
 
     QGridLayout *gl1 = new QGridLayout(gb1);
     gl1->addWidget(new QLabel( tr("X= ")), 0, 0);
@@ -415,13 +445,15 @@ void PlotDialog::initLayerGeometryPage()
     gl1->setRowStretch(2, 1);
 
     QGroupBox *gb2 = new QGroupBox(tr("Size"));
-    boxLayerWidth = new QSpinBox();
-	boxLayerWidth->setRange(0, 2000);
-	boxLayerWidth->setSuffix(tr(" pixels"));
+    boxLayerWidth = new DoubleSpinBox();
+	boxLayerWidth->setMinimum(0);
+	boxLayerWidth->setLocale(locale);
+	boxLayerWidth->setDecimals(6);
 
-	boxLayerHeight = new QSpinBox();
-	boxLayerHeight->setRange(0, 2000);
-	boxLayerHeight->setSuffix(tr(" pixels"));
+	boxLayerHeight = new DoubleSpinBox();
+	boxLayerHeight->setMinimum(0);
+	boxLayerHeight->setLocale(locale);
+	boxLayerHeight->setDecimals(6);
 
     QGridLayout *gl2 = new QGridLayout(gb2);
     gl2->addWidget(new QLabel( tr("width= ")), 0, 0);
@@ -436,17 +468,19 @@ void PlotDialog::initLayerGeometryPage()
 
     gl2->setRowStretch(4, 1);
 
-    QBoxLayout *bl1 = new QBoxLayout (QBoxLayout::LeftToRight);
-	bl1->addWidget(gb1);
-	bl1->addWidget(gb2);
+    QBoxLayout *bl2 = new QBoxLayout (QBoxLayout::LeftToRight);
+	bl2->addWidget(gb1);
+	bl2->addWidget(gb2);
 
-    QHBoxLayout * hl = new QHBoxLayout( layerGeometryPage );
-    hl->addLayout(bl1);
+    QVBoxLayout * vl = new QVBoxLayout( layerGeometryPage );
+    vl->addLayout(bl1);
+	vl->addLayout(bl2);
 
     privateTabWidget->addTab(layerGeometryPage, tr("Geometry"));
 
-	connect( boxLayerWidth, SIGNAL( valueChanged ( int ) ), this, SLOT( adjustLayerHeight(int) ) );
-	connect( boxLayerHeight, SIGNAL( valueChanged ( int ) ), this, SLOT( adjustLayerWidth(int) ) );
+	connect(boxLayerWidth, SIGNAL(valueChanged (double)), this, SLOT(adjustLayerHeight(double)));
+	connect(boxLayerHeight, SIGNAL(valueChanged (double)), this, SLOT(adjustLayerWidth(double)));
+	connect(unitBox, SIGNAL(activated(int)), this, SLOT(displayCoordinates(int)));
 }
 
 void PlotDialog::initPiePage()
@@ -460,12 +494,7 @@ void PlotDialog::initPiePage()
 	gl1->addWidget(boxPieLineColor, 0, 1);
 
 	gl1->addWidget(new QLabel(tr( "Style" )), 1, 0);
-	boxPieLineStyle = new QComboBox( false );
-	boxPieLineStyle->insertItem("_____");
-	boxPieLineStyle->insertItem("- - -");
-	boxPieLineStyle->insertItem(".....");
-	boxPieLineStyle->insertItem("_._._");
-	boxPieLineStyle->insertItem("_.._..");
+	boxPieLineStyle = new PenStyleBox();
 	gl1->addWidget(boxPieLineStyle);
 
 	gl1->addWidget(new QLabel(tr( "Width")), 2, 0);
@@ -724,13 +753,7 @@ void PlotDialog::initLinePage()
 	gl1->addWidget(boxConnect, 0, 1);
 
 	gl1->addWidget(new QLabel(tr( "Style" )), 1, 0);
-	boxLineStyle = new QComboBox();
-	boxLineStyle->setEditable(false);
-	boxLineStyle->addItem("_____");
-	boxLineStyle->addItem("_ _ _");
-	boxLineStyle->addItem(".....");
-	boxLineStyle->addItem("_._._");
-	boxLineStyle->addItem("_.._..");
+	boxLineStyle = new PenStyleBox();
 	gl1->addWidget(boxLineStyle, 1, 1);
 
 	gl1->addWidget(new QLabel(tr( "Width" )), 2, 0);
@@ -1045,13 +1068,7 @@ void PlotDialog::initSpectrogramPage()
     gl1->addWidget(contourWidthBox, 1, 1);
 
     gl1->addWidget(new QLabel(tr( "Style" )), 2, 0);
-  	boxContourStyle = new QComboBox();
-	boxContourStyle->setEditable(false);
-  	boxContourStyle->addItem("_____");
-  	boxContourStyle->addItem("_ _ _");
-  	boxContourStyle->addItem(".....");
-  	boxContourStyle->addItem("_._._");
-  	boxContourStyle->addItem("_.._..");
+  	boxContourStyle = new PenStyleBox();
     gl1->addWidget(boxContourStyle, 2, 1);
     hl2->addWidget(defaultPenBox);
 
@@ -1272,6 +1289,7 @@ void PlotDialog::setMultiLayer(MultiLayer *ml)
         return;
 
     d_ml = ml;
+
 	boxScaleLayers->setChecked(d_ml->scaleLayersOnPrint());
 	boxPrintCrops->setChecked(d_ml->printCropmarksEnabled());
 
@@ -1303,6 +1321,7 @@ void PlotDialog::selectCurve(int index)
         return;
 	QTreeWidgetItem *item = layerItem->child(index);
 	if (item){
+		listBox->scrollToItem(item);
 	    ((CurveTreeItem *)item)->setActive(true);
         listBox->setCurrentItem(item);
 	}
@@ -1407,11 +1426,11 @@ void PlotDialog::removeSelectedCurve()
 
 		LayerItem *layerItem = (LayerItem *)item->parent();
 		QTreeWidgetItem *rootItem = layerItem->parent();
-		
+
 		int index = rootItem->indexOfChild (layerItem);
 		rootItem->takeChild(index);
         delete layerItem;
-		
+
 		layerItem = new LayerItem(graph, rootItem, tr("Layer") + QString::number(d_ml->layerIndex(graph) + 1));
         rootItem->addChild(layerItem);
 		if (graph->curveCount() > 0){
@@ -1428,7 +1447,7 @@ void PlotDialog::removeSelectedCurve()
             privateTabWidget->addTab (layerPage, tr("Layer"));
 			privateTabWidget->addTab (layerGeometryPage, tr("Geometry"));
             privateTabWidget->showPage(layerPage);
-			
+
 			setActiveLayer(layerItem);
 		}
     }
@@ -1529,13 +1548,13 @@ void PlotDialog::updateTabWindow(QTreeWidgetItem *currentItem, QTreeWidgetItem *
 {
 	if (!currentItem)
         return;
-	
+
 	bool forceClearTabs = false;
 	if (!previousItem){
 		previousItem = currentItem;
 		forceClearTabs = true;
 	}
-	
+
     if (previousItem->type() == CurveTreeItem::PlotCurveTreeItem)
         ((CurveTreeItem *)previousItem)->setActive(false);
     else if (previousItem->type() == LayerItem::LayerTreeItem)
@@ -1579,8 +1598,7 @@ void PlotDialog::updateTabWindow(QTreeWidgetItem *currentItem, QTreeWidgetItem *
 
 void PlotDialog::insertTabs(int plot_type)
 {
-    if (plot_type == Graph::Pie)
-	{
+    if (plot_type == Graph::Pie){
 		privateTabWidget->addTab (piePage, tr("Pattern"));
 		privateTabWidget->addTab (pieGeometryPage, tr("Pie Geometry"));
 		privateTabWidget->addTab (pieLabelsPage, tr("Labels"));
@@ -1589,65 +1607,48 @@ void PlotDialog::insertTabs(int plot_type)
 	}
 
     privateTabWidget->addTab (axesPage, tr("Axes"));
-	if (plot_type == Graph::Line)
-	{
+	if (plot_type == Graph::Line){
 		boxConnect->setEnabled(true);
 		privateTabWidget->addTab (linePage, tr("Line"));
 		privateTabWidget->showPage(linePage);
-	}
-	else if (plot_type == Graph::Scatter)
-	{
+	} else if (plot_type == Graph::Scatter){
 		boxConnect->setEnabled(true);
 		privateTabWidget->addTab (symbolPage, tr("Symbol"));
 		privateTabWidget->showPage(symbolPage);
-	}
-	else if (plot_type == Graph::LineSymbols)
-	{
+	} else if (plot_type == Graph::LineSymbols){
 		boxConnect->setEnabled(true);
 		privateTabWidget->addTab (linePage, tr("Line"));
 		privateTabWidget->addTab (symbolPage, tr("Symbol"));
 		privateTabWidget->showPage(symbolPage);
-	}
-	else if (plot_type == Graph::VerticalBars ||
+	} else if (plot_type == Graph::VerticalBars ||
 			plot_type == Graph::HorizontalBars ||
-			plot_type == Graph::Histogram)
-	{
+			plot_type == Graph::Histogram){
 		boxConnect->setEnabled(false);
 		privateTabWidget->addTab (linePage, tr("Pattern"));
 		privateTabWidget->addTab (spacingPage, tr("Spacing"));
 
-		if (plot_type == Graph::Histogram)
-		{
+		if (plot_type == Graph::Histogram){
 			privateTabWidget->addTab (histogramPage, tr("Histogram Data"));
 			privateTabWidget->showPage(histogramPage);
-		}
-		else
+		} else
 			privateTabWidget->showPage(linePage);
-	}
-	else if (plot_type == Graph::VectXYXY || plot_type == Graph::VectXYAM)
-	{
+	} else if (plot_type == Graph::VectXYXY || plot_type == Graph::VectXYAM){
 		boxConnect->setEnabled(true);
 		privateTabWidget->addTab (linePage, tr("Line"));
 		privateTabWidget->addTab (vectPage, tr("Vector"));
 		customVectorsPage(plot_type == Graph::VectXYAM);
 		privateTabWidget->showPage(vectPage);
-	}
-	else if (plot_type == Graph::ErrorBars)
-	{
+	} else if (plot_type == Graph::ErrorBars){
 		privateTabWidget->addTab (errorsPage, tr("Error Bars"));
 		privateTabWidget->showPage(errorsPage);
-	}
-	else if (plot_type == Graph::Box)
-	{
+    } else if (plot_type == Graph::Box) {
 		boxConnect->setEnabled(false);
 		privateTabWidget->addTab (linePage, tr("Pattern"));
 		privateTabWidget->addTab (boxPage, tr("Box/Whiskers"));
 		privateTabWidget->addTab (percentilePage, tr("Percentile"));
 		privateTabWidget->showPage(linePage);
 		return;
-	}
-	else if (plot_type == Graph::ColorMap || plot_type == Graph::GrayScale || plot_type == Graph::Contour)
-  	{
+	} else if (plot_type == Graph::ColorMap || plot_type == Graph::GrayScale || plot_type == Graph::Contour){
   		privateTabWidget->addTab(spectrogramPage, tr("Colors") + " / " + tr("Contour"));
   	    privateTabWidget->showPage(spectrogramPage);
   	    return;
@@ -1658,7 +1659,7 @@ void PlotDialog::insertTabs(int plot_type)
         return;
 
     DataCurve *c = (DataCurve *)((CurveTreeItem *)item)->plotItem();
-    if (c && c->type() != Graph::Function){
+    if (c && c->type() != Graph::Function && c->type() != Graph::ErrorBars){
         privateTabWidget->addTab (labelsPage, tr("Labels"));
 		if (c->hasSelectedLabels())
 			privateTabWidget->showPage(labelsPage);
@@ -1773,6 +1774,11 @@ void PlotDialog::setActiveLayer(LayerItem *item)
     btnWorksheet->hide();
     btnEditCurve->hide();
 
+    boxBorderColor->blockSignals(true);
+    boxBackgroundColor->blockSignals(true);
+    boxCanvasColor->blockSignals(true);
+    boxAntialiasing->blockSignals(true);
+    boxMargin->blockSignals(true);
     boxBackgroundTransparency->blockSignals(true);
     boxCanvasTransparency->blockSignals(true);
     boxBorderWidth->blockSignals(true);
@@ -1795,22 +1801,24 @@ void PlotDialog::setActiveLayer(LayerItem *item)
 
 	boxAntialiasing->setChecked(g->antialiasing());
 
-    boxBackgroundTransparency->blockSignals(false);
-    boxCanvasTransparency->blockSignals(false);
-    boxBorderWidth->blockSignals(false);
-
-	boxX->setValue(g->pos().x());
-	boxY->setValue(g->pos().y());
-
 	boxLayerWidth->blockSignals(true);
-	boxLayerWidth->setValue(g->width());
-	boxLayerWidth->blockSignals(false);
-
 	boxLayerHeight->blockSignals(true);
-	boxLayerHeight->setValue(g->height());
+
+	displayCoordinates(unitBox->currentIndex(), g);
+
+	boxLayerWidth->blockSignals(false);
 	boxLayerHeight->blockSignals(false);
 
 	aspect_ratio = (double)g->width()/(double)g->height();
+
+    boxBackgroundTransparency->blockSignals(false);
+    boxCanvasTransparency->blockSignals(false);
+    boxBorderWidth->blockSignals(false);
+    boxBorderColor->blockSignals(false);
+    boxBackgroundColor->blockSignals(false);
+    boxCanvasColor->blockSignals(false);
+    boxAntialiasing->blockSignals(false);
+    boxMargin->blockSignals(false);
 }
 
 void PlotDialog::setActiveCurve(CurveTreeItem *item)
@@ -1823,6 +1831,7 @@ void PlotDialog::setActiveCurve(CurveTreeItem *item)
         return;
 
 	item->setActive(true);
+	listBox->scrollToItem(item);
 	btnWorksheet->show();
     btnEditCurve->show();
 
@@ -1873,7 +1882,7 @@ void PlotDialog::setActiveCurve(CurveTreeItem *item)
         boxPiePattern->setPattern(pie->pattern());
         boxPieLineWidth->setValue(pie->pen().widthF());
         boxPieLineColor->setColor(pie->pen().color());
-        setPiePenStyle(pie->pen().style());
+        boxPieLineStyle->setStyle(pie->pen().style());
         boxFirstColor->setCurrentIndex(pie->firstColor());
 
         boxPieViewAngle->blockSignals(true);
@@ -1914,7 +1923,7 @@ void PlotDialog::setActiveCurve(CurveTreeItem *item)
         style = 6;
     boxConnect->setCurrentIndex(style);
 
-    setPenStyle(c->pen().style());
+	boxLineStyle->setStyle(c->pen().style());
     boxLineColor->setColor(c->pen().color());
 	boxLineWidth->blockSignals(true);
     boxLineWidth->setValue(c->pen().widthF());
@@ -2057,7 +2066,7 @@ void PlotDialog::setActiveCurve(CurveTreeItem *item)
 	boxLabelsXOffset->blockSignals(true);
     boxLabelsXOffset->setValue(dc->labelsXOffset());
 	boxLabelsXOffset->blockSignals(false);
-	
+
 	boxLabelsYOffset->blockSignals(true);
     boxLabelsYOffset->setValue(dc->labelsYOffset());
 	boxLabelsYOffset->blockSignals(false);
@@ -2098,6 +2107,75 @@ void PlotDialog::updateEndPointColumns(const QString& text)
 	yEndBox->setCurrentText(table + "_" + cols[3].remove("(Y)").remove("(M)"));
 }
 
+void PlotDialog::applyLayerFormat()
+{
+	if (privateTabWidget->currentWidget() != layerPage)
+		return;
+
+	ApplicationWindow *app = (ApplicationWindow *)this->parent();
+	switch(backgroundApplyToBox->currentIndex()){
+		case 0://this layer
+		{
+			LayerItem *item = (LayerItem *)listBox->currentItem();
+        	if (!item)
+            	return;
+
+        	Graph *g = item->graph();
+			if (!g)
+				return;
+
+			applyFormatToLayer(g);
+		}
+		break;
+
+		case 1://this window
+		{
+			QList<Graph *> layersLst = d_ml->layersList();
+			foreach(Graph *g, layersLst)
+				applyFormatToLayer(g);
+		}
+		break;
+
+		case 2://all windows
+		{
+			QList<MdiSubWindow *> windows = app->windowsList();
+			foreach(MdiSubWindow *w, windows){
+				MultiLayer *ml = qobject_cast<MultiLayer *>(w);
+				if (!ml)
+					continue;
+
+				QList<Graph *> layersLst = ml->layersList();
+				foreach(Graph *g, layersLst)
+					applyFormatToLayer(g);
+			}
+		}
+		break;
+
+		default:
+			break;
+	}
+	app->modifiedProject();
+}
+
+void PlotDialog::applyFormatToLayer(Graph *g)
+{
+	if (!g)
+		return;
+
+	g->setFrame(boxBorderWidth->value(), boxBorderColor->color());
+	g->setMargin(boxMargin->value());
+
+	QColor c = boxBackgroundColor->color();
+	c.setAlpha(boxBackgroundTransparency->value());
+	g->setBackgroundColor(c);
+
+	c = boxCanvasColor->color();
+	c.setAlpha(boxCanvasTransparency->value());
+	g->setCanvasBackground(c);
+
+	g->setAntialiasing(boxAntialiasing->isChecked());
+}
+
 bool PlotDialog::acceptParams()
 {
     if (privateTabWidget->currentWidget() == fontsPage){
@@ -2107,27 +2185,10 @@ bool PlotDialog::acceptParams()
 		d_ml->setScaleLayersOnPrint(boxScaleLayers->isChecked());
 		d_ml->printCropmarks(boxPrintCrops->isChecked());
 		return true;
-    } else if (privateTabWidget->currentWidget() == layerPage){
-		if (!boxAll->isChecked())
-			return true;
-
-		QList<Graph *> layers = d_ml->layersList();
-        foreach(Graph *g, layers){
-            g->setFrame(boxBorderWidth->value(), boxBorderColor->color());
-            g->setMargin(boxMargin->value());
-
-            QColor c = boxBackgroundColor->color();
-            c.setAlpha(boxBackgroundTransparency->value());
-            g->setBackgroundColor(c);
-
-            c = boxCanvasColor->color();
-            c.setAlpha(boxCanvasTransparency->value());
-            g->setCanvasBackground(c);
-
-            g->setAntialiasing(boxAntialiasing->isChecked());
-		}
+    } else if (privateTabWidget->currentWidget() == layerPage)
+		//all changes are already applied by the different GUI objects in the layer tab
 		return true;
-	} else if (privateTabWidget->currentWidget() == layerGeometryPage){
+	else if (privateTabWidget->currentWidget() == layerGeometryPage){
 		LayerItem *item = (LayerItem *)listBox->currentItem();
         if (!item)
             return false;
@@ -2135,12 +2196,8 @@ bool PlotDialog::acceptParams()
 		if (!g)
 			return false;
 
-		QPoint pos = QPoint(boxX->value(), boxY->value());
-		QSize size = QSize(boxLayerWidth->value(), boxLayerHeight->value());
-		if (g->pos() == pos && g->size() == size)
-			return true;
-
-		g->setGeometry(QRect(pos, size));
+		FrameWidget::setRect(g, boxX->value(), boxY->value(), boxLayerWidth->value(),
+					boxLayerHeight->value(), (FrameWidget::Unit)unitBox->currentIndex());
 		d_ml->repaint();
 		return true;
 	}
@@ -2171,8 +2228,7 @@ bool PlotDialog::acceptParams()
   	    if (autoContourBox->isChecked())
   	    	sp->setDefaultContourPen(Qt::NoPen);
   	    else
-  	    	sp->setDefaultContourPen(QPen(levelsColorBox->color(), contourWidthBox->value(),
-  	                            Graph::getPenStyle(boxContourStyle->currentItem())));
+  	    	sp->setDefaultContourPen(QPen(levelsColorBox->color(), contourWidthBox->value(), boxContourStyle->style()));
 
   	   sp->setDisplayMode(QwtPlotSpectrogram::ContourMode, levelsGroupBox->isChecked());
   	   sp->setDisplayMode(QwtPlotSpectrogram::ImageMode, imageGroupBox->isChecked());
@@ -2197,7 +2253,7 @@ bool PlotDialog::acceptParams()
 		QBrush br = QBrush(boxAreaColor->color(), boxPattern->getSelectedPattern());
 		if (!fillGroupBox->isChecked())
 			br = QBrush();
-		QPen pen = QPen(boxLineColor->color(), boxLineWidth->value(), Graph::getPenStyle(boxLineStyle->currentIndex()));
+		QPen pen = QPen(boxLineColor->color(), boxLineWidth->value(), boxLineStyle->style());
 		QwtPlotCurve *curve = (QwtPlotCurve *)plotItem;
 		curve->setPen(pen);
 		curve->setBrush(br);
@@ -2241,7 +2297,7 @@ bool PlotDialog::acceptParams()
 		if (!w)
 			return false;
 
-		graph->updateVectorsLayout(item->plotItemIndex(), vectColorBox->color(), 
+		graph->updateVectorsLayout(item->plotItemIndex(), vectColorBox->color(),
 				vectWidthBox->value(), headLengthBox->value(), headAngleBox->value(),
 				filledHeadBox->isChecked(), vectPosBox->currentIndex(), xEndCol, yEndCol);
 
@@ -2271,8 +2327,7 @@ bool PlotDialog::acceptParams()
         return true;
 	} else if (privateTabWidget->currentPage() == piePage){
 		QwtPieCurve *pie = (QwtPieCurve*)plotItem;
-		pie->setPen(QPen(boxPieLineColor->color(), boxPieLineWidth->value(),
-                    Graph::getPenStyle(boxPieLineStyle->currentIndex())));
+		pie->setPen(QPen(boxPieLineColor->color(), boxPieLineWidth->value(), boxPieLineStyle->style()));
         pie->setBrushStyle(boxPiePattern->getSelectedPattern());
         pie->setFirstColor(boxFirstColor->currentIndex());
 	} else if (privateTabWidget->currentPage() == pieGeometryPage){
@@ -2479,43 +2534,6 @@ bool PlotDialog::validInput()
 
 	return true;
 }
-void PlotDialog::setPiePenStyle(const Qt::PenStyle& style)
-{
-	if(style == Qt::SolidLine)
-		boxPieLineStyle->setCurrentItem(0);
-	if(style == Qt::DashLine)
-		boxPieLineStyle->setCurrentItem(1);
-	if(style == Qt::DotLine)
-		boxPieLineStyle->setCurrentItem(2);
-	if(style == Qt::DashDotLine)
-		boxPieLineStyle->setCurrentItem(3);
-	if(style == Qt::DashDotDotLine)
-		boxPieLineStyle->setCurrentItem(4);
-}
-
-void PlotDialog::setPenStyle(Qt::PenStyle style)
-{
-	switch (style)
-	{
-		case Qt::SolidLine:
-			boxLineStyle->setCurrentIndex(0);
-			break;
-		case Qt::DashLine:
-			boxLineStyle->setCurrentIndex(1);
-			break;
-		case Qt::DotLine:
-			boxLineStyle->setCurrentIndex(2);
-			break;
-		case Qt::DashDotLine:
-			boxLineStyle->setCurrentIndex(3);
-			break;
-		case Qt::DashDotDotLine:
-			boxLineStyle->setCurrentIndex(4);
-			break;
-		default:
-			break;
-	}
-}
 
 void PlotDialog::setBoxType(int index)
 {
@@ -2636,215 +2654,45 @@ void PlotDialog::updateTreeWidgetItem(QTreeWidgetItem *item)
 void PlotDialog::updateBackgroundTransparency(int alpha)
 {
 	boxBackgroundColor->setEnabled(alpha);
-    QColor c = boxBackgroundColor->color();
-    c.setAlpha(boxBackgroundTransparency->value());
-
-	if (boxAll->isChecked()){
-		QList<Graph *> layers = d_ml->layersList();
-        foreach(Graph *g, layers)
-            g->setBackgroundColor(c);
-	} else {
-	    LayerItem *item = (LayerItem *)listBox->currentItem();
-        if (!item)
-            return;
-        Graph *g = item->graph();
-		if (g)
-			g->setBackgroundColor(c);
-	}
+	applyLayerFormat();
 }
 
 void PlotDialog::updateCanvasTransparency(int alpha)
 {
     boxCanvasColor->setEnabled(alpha);
-    QColor c = boxCanvasColor->color();
-    c.setAlpha(boxCanvasTransparency->value());
-
-	if (boxAll->isChecked()){
-		QList<Graph *> layers = d_ml->layersList();
-        foreach(Graph *g, layers)
-            g->setCanvasBackground(c);
-	} else {
-		LayerItem *item = (LayerItem *)listBox->currentItem();
-        if (!item)
-            return;
-        Graph *g = item->graph();
-		if (g)
-			g->setCanvasBackground(c);
-	}
-}
-
-void PlotDialog::pickCanvasColor()
-{
-	QColor c = boxCanvasColor->color();
-    c.setAlpha(boxCanvasTransparency->value());
-
-	if (boxAll->isChecked()){
-		QList<Graph *> layers = d_ml->layersList();
-        foreach(Graph *g, layers){
-            g->setCanvasBackground(c);
-            g->replot();
-        }
-	} else {
-		LayerItem *item = (LayerItem *)listBox->currentItem();
-        if (!item)
-            return;
-        Graph *g = item->graph();
-		if (g){
-			g->setCanvasBackground(c);
-			g->replot();
-		}
-	}
-}
-
-void PlotDialog::pickBackgroundColor()
-{
-	QColor c = boxBackgroundColor->color();
-    c.setAlpha(boxBackgroundTransparency->value());
-
-	if (boxAll->isChecked()){
-		QList<Graph *> layers = d_ml->layersList();
-        foreach(Graph *g, layers){
-            g->setBackgroundColor(c);
-            g->replot();
-		}
-	} else {
-		LayerItem *item = (LayerItem *)listBox->currentItem();
-        if (!item)
-            return;
-        Graph *g = item->graph();
-		if (g){
-			g->setBackgroundColor(c);
-			g->replot();
-		}
-	}
-}
-
-void PlotDialog::pickBorderColor()
-{
-	if (boxAll->isChecked()){
-		QList<Graph *> layers = d_ml->layersList();
-        foreach(Graph *g, layers)
-            g->setFrame(boxBorderWidth->value(), boxBorderColor->color());
-	} else {
-		LayerItem *item = (LayerItem *)listBox->currentItem();
-        if (!item)
-            return;
-        Graph *g = item->graph();
-		if (g)
-			g->setFrame(boxBorderWidth->value(), boxBorderColor->color());
-	}
-	d_ml->notifyChanges();
-}
-
-void PlotDialog::updateAntialiasing(bool on)
-{
-	if (privateTabWidget->currentWidget() != layerPage)
-		return;
-
-	if (boxAll->isChecked())
-	{
-		QList<Graph *> layers = d_ml->layersList();
-        foreach(Graph *g, layers)
-            g->setAntialiasing(on);
-	}
-	else
-	{
-		LayerItem *item = (LayerItem *)listBox->currentItem();
-        if (!item)
-            return;
-        Graph *g = item->graph();
-		if (g)
-			g->setAntialiasing(on);
-	}
-}
-
-void PlotDialog::updateBorder(int width)
-{
-	if (privateTabWidget->currentWidget() != layerPage)
-		return;
-
-	if (boxAll->isChecked())
-	{
-		QList<Graph *> layers = d_ml->layersList();
-        foreach(Graph *g, layers)
-            g->setFrame(width, boxBorderColor->color());
-	}
-	else
-	{
-		LayerItem *item = (LayerItem *)listBox->currentItem();
-        if (!item)
-            return;
-        Graph *g = item->graph();
-		if (g)
-			g->setFrame(width, boxBorderColor->color());
-	}
-	d_ml->notifyChanges();
-}
-
-void PlotDialog::changeMargin(int width)
-{
-	if (privateTabWidget->currentWidget() != layerPage)
-		return;
-
-    if (boxAll->isChecked())
-    {
-        QList<Graph *> layers = d_ml->layersList();
-        foreach(Graph *g, layers)
-            g->setMargin(width);
-    }
-    else
-    {
-        LayerItem *item = (LayerItem *)listBox->currentItem();
-        if (!item)
-            return;
-        Graph *g = item->graph();
-        if (g)
-            g->setMargin(width);
-    }
+	applyLayerFormat();
 }
 
 void PlotDialog::setTitlesFont()
 {
 	bool ok;
 	QFont font = QFontDialog::getFont(&ok,titleFont,this);
-	if ( ok ) {
+	if ( ok )
 		titleFont = font;
-	} else {
-		return;
-	}
 }
 
 void PlotDialog::setAxesLabelsFont()
 {
 	bool ok;
 	QFont font = QFontDialog::getFont(&ok,axesFont,this);
-	if ( ok ) {
+	if ( ok )
 		axesFont = font;
-	} else {
-		return;
-	}
 }
 
 void PlotDialog::setAxesNumbersFont()
 {
 	bool ok;
 	QFont font = QFontDialog::getFont(&ok,numbersFont,this);
-	if ( ok ) {
+	if ( ok )
 		numbersFont = font;
-	} else {
-		return;
-	}
 }
 
 void PlotDialog::setLegendsFont()
 {
 	bool ok;
 	QFont font = QFontDialog::getFont(&ok, legendFont,this);
-	if ( ok ) {
+	if ( ok )
 		legendFont = font;
-	} else {
-		return;
-	}
 }
 
 void PlotDialog::initFonts(const QFont& titlefont, const QFont& axesfont, const QFont& numbersfont, const QFont& legendfont)
@@ -2855,24 +2703,24 @@ void PlotDialog::initFonts(const QFont& titlefont, const QFont& axesfont, const
 	legendFont = legendfont;
 }
 
-void PlotDialog::adjustLayerHeight(int width)
+void PlotDialog::adjustLayerHeight(double width)
 {
 	if (keepRatioBox->isChecked()){
-		disconnect( boxLayerHeight, SIGNAL( valueChanged ( int ) ), this, SLOT( adjustLayerWidth(int) ) );
-		boxLayerHeight->setValue(int(width/aspect_ratio));
-		connect( boxLayerHeight, SIGNAL( valueChanged ( int ) ), this, SLOT( adjustLayerWidth(int) ) );
+		boxLayerHeight->blockSignals(true);
+		boxLayerHeight->setValue(width/aspect_ratio);
+		boxLayerHeight->blockSignals(false);
 	} else
-		aspect_ratio = (double)width/double(boxLayerHeight->value());
+		aspect_ratio = width/boxLayerHeight->value();
 }
 
-void PlotDialog::adjustLayerWidth(int height)
+void PlotDialog::adjustLayerWidth(double height)
 {
 	if (keepRatioBox->isChecked()){
-		disconnect( boxLayerWidth, SIGNAL( valueChanged ( int ) ), this, SLOT( adjustLayerHeight(int) ) );
-		boxLayerWidth->setValue(int(height*aspect_ratio));
-		connect( boxLayerWidth, SIGNAL( valueChanged ( int ) ), this, SLOT( adjustLayerHeight(int) ) );
+		boxLayerWidth->blockSignals(true);
+		boxLayerWidth->setValue(height*aspect_ratio);
+		boxLayerWidth->blockSignals(false);
 	} else
-		aspect_ratio = double(boxLayerWidth->value())/(double)height;
+		aspect_ratio = boxLayerWidth->value()/height;
 }
 
 void PlotDialog::closeEvent(QCloseEvent* e)
@@ -2925,6 +2773,65 @@ int PlotDialog::labelsAlignment()
 	return align;
 }
 
+void PlotDialog::displayCoordinates(int unit, Graph *g)
+{
+	if (!g){
+		QTreeWidgetItem *item = listBox->currentItem();
+    	if (item){
+        	g = ((LayerItem *)item)->graph();
+			if (!g)
+				return;
+		}
+	}
+
+	if (unit == FrameWidget::Pixel || unit == FrameWidget::Point){
+		boxX->setFormat('f', 0);
+		boxY->setFormat('f', 0);
+		boxLayerWidth->setFormat('f', 0);
+		boxLayerHeight->setFormat('f', 0);
+
+		boxX->setSingleStep(1.0);
+		boxY->setSingleStep(1.0);
+		boxLayerWidth->setSingleStep(1.0);
+		boxLayerHeight->setSingleStep(1.0);
+	} else {
+		boxX->setFormat('g', 6);
+		boxY->setFormat('g', 6);
+		boxLayerWidth->setFormat('g', 6);
+		boxLayerHeight->setFormat('g', 6);
+
+		boxX->setSingleStep(0.1);
+		boxY->setSingleStep(0.1);
+		boxLayerWidth->setSingleStep(0.1);
+		boxLayerHeight->setSingleStep(0.1);
+	}
+
+	boxX->setValue(FrameWidget::xIn(g, (FrameWidget::Unit)unit));
+	boxY->setValue(FrameWidget::yIn(g, (FrameWidget::Unit)unit));
+	boxLayerWidth->setValue(FrameWidget::widthIn(g, (FrameWidget::Unit)unit));
+	boxLayerHeight->setValue(FrameWidget::heightIn(g, (FrameWidget::Unit)unit));
+
+	aspect_ratio = boxLayerWidth->value()/boxLayerHeight->value();
+}
+
+void PlotDialog::setLayerDefaultValues()
+{
+	ApplicationWindow *app = (ApplicationWindow *)this->parent();
+	if (!app)
+		return;
+
+    app->d_graph_background_color = boxBackgroundColor->color();
+	app->d_graph_background_opacity = boxBackgroundTransparency->value();
+	app->d_graph_canvas_color = boxCanvasColor->color();
+	app->d_graph_canvas_opacity = boxCanvasTransparency->value();
+	app->d_graph_border_color = boxBorderColor->color();
+	app->d_graph_border_width = boxBorderWidth->value();
+	app->defaultPlotMargin = boxMargin->value();
+	app->antialiasing2DPlots = boxAntialiasing->isChecked();
+
+	app->saveSettings();
+}
+
 /*****************************************************************************
  *
  * Class LayerItem
@@ -3006,8 +2913,8 @@ int CurveTreeItem::plotItemType()
 {
 	if (d_curve->rtti() != QwtPlotItem::Rtti_PlotSpectrogram)
 		return ((PlotCurve *)d_curve)->plotStyle();
-	else 
+	else
 		return Graph::ColorMap;
-	
+
 	return -1;
 }
