@@ -58,6 +58,7 @@ class SymbolBox;
 class ColorMapEditor;
 class QwtPlotItem;
 class DoubleSpinBox;
+class PenStyleBox;
 
 static const char* folder_closed[]={
     "16 16 9 1",
@@ -251,9 +252,6 @@ private slots:
 	bool validInput();
 	void showPlotAssociations(QTreeWidgetItem *item, int);
 
-	void setPenStyle(Qt::PenStyle style);
-	void setPiePenStyle(const Qt::PenStyle& style);
-
 	//box plots
 	void setBoxType(int index);
 	void setBoxRangeType(int index);
@@ -264,28 +262,26 @@ private slots:
 	void showColorMapEditor(bool show);
 
 	//layer geometry
-	void adjustLayerHeight(int width);
-	void adjustLayerWidth(int height);
+	void adjustLayerHeight(double width);
+	void adjustLayerWidth(double height);
+	void displayCoordinates(int unit, Graph *g = 0);
 
 protected slots:
     void setActiveLayer(LayerItem *item);
     void updateTreeWidgetItem(QTreeWidgetItem *item);
     void updateBackgroundTransparency(int alpha);
     void updateCanvasTransparency(int alpha);
-    void updateAntialiasing(bool on);
-    void updateBorder(int width);
-	void pickBackgroundColor();
-	void pickCanvasColor();
-	void pickBorderColor();
-	void changeMargin(int);
 	void setTitlesFont();
 	void setAxesLabelsFont();
 	void setAxesNumbersFont();
 	void setLegendsFont();
 	void editCurve();
 	void chooseLabelsFont();
+	void applyLayerFormat();
+	void setLayerDefaultValues();
 
 private:
+	void applyFormatToLayer(Graph *g);
     int labelsAlignment();
 	void closeEvent(QCloseEvent* e);
 
@@ -317,21 +313,21 @@ private:
     MultiLayer *d_ml;
 	QStringList columnNames;
 
-	QSpinBox* boxX, *boxY, *boxLayerWidth, *boxLayerHeight;
+	DoubleSpinBox* boxX, *boxY, *boxLayerWidth, *boxLayerHeight;
 	QCheckBox *keepRatioBox;
 
     QPushButton *btnTitle, *btnAxesLabels, *btnAxesNumbers, *btnLegend;
 	ColorMapEditor *colorMapEditor;
     QWidget *curvePlotTypeBox, *layerPage, *layerGeometryPage, *piePage, *fontsPage, *printPage;
     QTreeWidget* listBox;
-    QCheckBox *boxAntialiasing, *boxAll, *boxScaleLayers, *boxPrintCrops;
+    QCheckBox *boxAntialiasing, *boxScaleLayers, *boxPrintCrops;
     ColorButton *boxBorderColor, *boxBackgroundColor, *boxCanvasColor;
 	QSpinBox *boxBackgroundTransparency, *boxCanvasTransparency, *boxBorderWidth, *boxMargin;
 	QSpinBox *boxRadius;
 	DoubleSpinBox *boxPieLineWidth;
     ColorBox *boxFirstColor, *boxPieLineColor;
     PatternBox *boxPiePattern;
-    QComboBox* boxPieLineStyle;
+    PenStyleBox* boxPieLineStyle;
 
     QPushButton* buttonApply, *btnWorksheet;
     QPushButton* buttonOk, *btnMore;
@@ -339,7 +335,7 @@ private:
     QComboBox* boxPlotType;
     QWidget* linePage;
     QComboBox* boxConnect;
-    QComboBox* boxLineStyle;
+    PenStyleBox* boxLineStyle;
     DoubleSpinBox *boxLineWidth, *boxPenWidth;
     ColorBox* boxLineColor, *boxAreaColor;
     QWidget* symbolPage;
@@ -376,7 +372,8 @@ private:
 	QLabel 	*whiskerCoeffLabel, *whiskerRangeLabel, *boxCoeffLabel;
 	QLabel *boxRangeLabel, *whiskerCntLabel, *boxCntLabel;
 	QGroupBox *GroupBoxVectEnd;
-	QComboBox *vectPosBox, *boxXAxis, *boxYAxis, *colorScaleBox, *boxContourStyle;
+	QComboBox *vectPosBox, *boxXAxis, *boxYAxis, *colorScaleBox;
+	PenStyleBox	*boxContourStyle;
   	QSpinBox *levelsBox, *colorScaleWidthBox;
 	DoubleSpinBox *contourWidthBox;
   	QGroupBox *levelsGroupBox, *axisScaleBox, *imageGroupBox;
@@ -401,6 +398,10 @@ private:
 	QWidget *pieLabelsPage;
     QSpinBox *boxPieOffset;
 	QWidget *pieGeometryPage;
+
+	QComboBox *unitBox;
+	QComboBox *backgroundApplyToBox;
+	QPushButton *layerDefaultBtn;
 };
 
 /*****************************************************************************
