@@ -27,7 +27,6 @@
  *                                                                         *
  ***************************************************************************/
 #include "Plot3DDialog.h"
-#include "../TextDialog.h"
 #include "../MyParser.h"
 #include "../SymbolDialog.h"
 #include "../ApplicationWindow.h"
@@ -498,10 +497,16 @@ void Plot3DDialog::setPlot(Graph3D *g)
 	boxTitle->setText(g->plotTitle());
 	titleFont = g->titleFont();
 
-	boxZoom->setValue(int(g->zoom()*100));
-	boxXScale->setValue(int(g->xScale()*100));
-	boxYScale->setValue(int(g->yScale()*100));
-	boxZScale->setValue(int(g->zScale()*100));
+    xScale = d_plot->xScale();
+    yScale = d_plot->yScale();
+    zScale = d_plot->zScale();
+    zoom = d_plot->zoom();
+
+    boxZoom->setValue(100);
+	boxXScale->setValue(100);
+	boxYScale->setValue(100);
+	boxZScale->setValue(100);
+
 	boxResolution->setValue(g->resolution());
 	boxLegend->setChecked(g->isLegendOn());
 	boxOrthogonal->setChecked(g->isOrthogonal());
@@ -700,8 +705,8 @@ void Plot3DDialog::changeZoom(int)
 		return;
 
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-	d_plot->setZoom(boxZoom->value()*0.01);
-    d_plot->setScale(boxXScale->value()*0.01, boxYScale->value()*0.01, boxZScale->value()*0.01);
+	d_plot->setZoom(zoom*boxZoom->value()*0.01);
+    d_plot->setScale(xScale*boxXScale->value()*0.01, yScale*boxYScale->value()*0.01, zScale*boxZScale->value()*0.01);
     d_plot->update();
     QApplication::restoreOverrideCursor();
 }
@@ -758,8 +763,8 @@ bool Plot3DDialog::updatePlot()
 		d_plot->setMeshLineWidth(boxMeshLineWidth->value());
 		d_plot->setLabelsDistance(boxDistance->value());
 		d_plot->setNumbersFont(numbersFont);
-		d_plot->setZoom(boxZoom->value()*0.01);
-		d_plot->setScale(boxXScale->value()*0.01, boxYScale->value()*0.01, boxZScale->value()*0.01);
+		d_plot->setZoom(zoom*boxZoom->value()*0.01);
+		d_plot->setScale(xScale*boxXScale->value()*0.01, yScale*boxYScale->value()*0.01, zScale*boxZScale->value()*0.01);
 	} else if (generalDialog->currentPage()==(QWidget*)scale){
 		int axis = axesList->currentRow();
 		QString from=boxFrom->text().lower();
